@@ -28,7 +28,7 @@
 #include <QtCore/QSharedPointer>
 #include <QtWidgets/QDialog>
 #include <QtGui/QStandardItemModel>
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QMenu>
 #include <QPointer>
 
