@@ -28,7 +28,7 @@
 #include "BookManipulation/FolderKeeper.h"
 #include "BookManipulation/XhtmlDoc.h"
 #include "Dialogs/HeadingSelector.h"
-#include "Misc/GumboInterface.h"
+#include "Parsers/GumboInterface.h"
 #include "Misc/SettingsStore.h"
 #include "Misc/Utility.h"
 #include "ResourceObjects/HTMLResource.h"
@@ -601,7 +601,7 @@ void HeadingSelector::DisplayCounts()
                       "<table cellpadding=\"5\">" +
                       "<tr><th>" + tr("Level") + "</th><th>" + tr("Included") + "</th><th>" + tr("Hidden") + "</th></tr>";
     foreach(QString h, HEADING_TAGS) {
-        tooltip += QString("<tr><td>%1</td><td>%2</td><td>%3</td></tr>").arg(h).arg(m_HeadingsIncluded[h]).arg(m_HeadingsHidden[h]);
+        tooltip += QString("<tr><td>%1</td><td style=\"text-align:right;\">%2</td><td style=\"text-align:right;\">%3</td></tr>").arg(h).arg(m_HeadingsIncluded[h]).arg(m_HeadingsHidden[h]);
     }
     tooltip += "</table>";
     ui.tvTOCDisplay->header()->setToolTip(tooltip);
@@ -973,7 +973,7 @@ void HeadingSelector::Rename()
 void HeadingSelector::CreateContextMenuActions()
 {
     m_Rename = new QAction(tr("Rename"),     this);
-    m_Rename->setShortcut(QKeySequence(Qt::ControlModifier + Qt::Key_R));
+    m_Rename->setShortcut(QKeySequence(Qt::ControlModifier | Qt::Key_R));
     // Has to be added to the dialog itself for the keyboard shortcut to work.
     addAction(m_Rename);
 }
@@ -1024,10 +1024,17 @@ void HeadingSelector::ConnectSignalsToSlots()
     connect(this,               SIGNAL(accepted()),
             this,               SLOT(UpdateHeadingElements())
            );
+    #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     connect(ui.cbTOCSetHeadingLevel,
             SIGNAL(activated(const QString &)),
             this,               SLOT(SelectHeadingLevelInclusion(const QString &))
            );
+    #else
+    connect(ui.cbTOCSetHeadingLevel,
+            SIGNAL(textActivated(const QString &)),
+            this,               SLOT(SelectHeadingLevelInclusion(const QString &))
+           );
+    #endif
     connect(ui.left,             SIGNAL(clicked()), this, SLOT(DecreaseHeadingLevel()));
     connect(ui.right,            SIGNAL(clicked()), this, SLOT(IncreaseHeadingLevel()));
     connect(ui.rename,           SIGNAL(clicked()), this, SLOT(Rename()));
