@@ -1,7 +1,7 @@
 /************************************************************************
  **
- **  Copyright (C) 2014-2020 Kevin B. Hendricks, Stratford Ontario Canada
- **  Copyright (C) 2020      Doug Massay
+ **  Copyright (C) 2014-2022 Kevin B. Hendricks, Stratford Ontario Canada
+ **  Copyright (C) 2020-2022 Doug Massay
  **
  **  This file is part of Sigil.
  **
@@ -62,7 +62,7 @@ PluginRunner::PluginRunner(TabManager *tabMgr, QWidget *parent)
       m_pluginName(""),
       m_pluginOutput(""),
       m_algorithm(""),
-      m_result(""),
+      m_result("failed"),
       m_xhtml_net_change(0),
       m_ready(false)
 
@@ -255,7 +255,14 @@ void PluginRunner::writeSigilCFG()
             cfg << "off";
             break;
     }
+    // handle automate and automate plugin parameter
     cfg << qApp->font().toString();
+    if (m_mainWindow->UsingAutomate()) {
+        cfg << "InAutomate";
+    } else {
+        cfg << "NoAutomate";
+    }
+    cfg << m_mainWindow->AutomatePluginParameter();
     QList <Resource *> selected_resources = m_bookBrowser->AllSelectedResources();
     foreach(Resource * resource, selected_resources) {
         cfg << resource->GetRelativePath();
@@ -311,26 +318,23 @@ void PluginRunner::startPlugin()
     args.append(QDir::toNativeSeparators(m_pluginPath));
     QString executable = QDir::toNativeSeparators(m_enginePath);
 
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
 #ifdef Q_OS_MAC
     // On Mac OS X, it appears that QProcess does not inherit the callers process environment at all
     // which directly contradicts the Qt documentation.
     // So we simply read the system environment and set it for QProcess manually
     // so that python getpreferredencoding() and stdout/stderr/stdin encodings to get properly set
-    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     if (settings.useBundledInterp()) {
          // determine path to site-packages/certifi/cacert.pem to set SSL_CERT_FILE
          QDir exedir(QCoreApplication::applicationDirPath());
-	 exedir.cdUp();
+         exedir.cdUp();
          QString cert_path = exedir.absolutePath() + PYTHON_SITE_PACKAGES + "/certifi/cacert.pem";
-	 env.insert("SSL_CERT_FILE", cert_path);
+         env.insert("SSL_CERT_FILE", cert_path);
          env.insert("QT_PLUGIN_PATH", QDir(QCoreApplication::applicationDirPath() + "/../PlugIns").absolutePath());
          env.insert("QT_QPA_PLATFORM_PLUGIN_PATH", QDir(QCoreApplication::applicationDirPath() + "/../PlugIns/platforms").absolutePath());
     }
-    m_process.setProcessEnvironment(env);
 #elif defined(Q_OS_WIN32)
     if (settings.useBundledInterp()) {
-        // Start with system environment.
-        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         // Set Python env variables to control how the bundled interpreter finds it's various pieces
         // (and to isolate the bundled interpreter from any system Python).
         // Relative to the interpreter binary to make it easier to relocate the bundled Python.
@@ -356,16 +360,12 @@ void PluginRunner::startPlugin()
         // Prepend Sigil program directory to PATH so the bundled interpreter
         // can find the correct Qt libs (for PyQt5) and the Python dll.
         env.insert("PATH", QDir::toNativeSeparators(QCoreApplication::applicationDirPath() + PATH_LIST_DELIM + env.value("PATH")));
-        // Set bundled Python environment.
-        m_process.setProcessEnvironment(env);
     }
     //Whether bundled or external, set working dir to the directory of the interpreter being used.
     m_process.setWorkingDirectory(QDir::toNativeSeparators(QFileInfo(m_enginePath).absolutePath()));
 #elif !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
     QString appdir = QCoreApplication::applicationDirPath();
     if (settings.useBundledInterp()) {  // Linux bundled Python settings
-        // Start with system environment.
-        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         // Set Python env variables to control how the bundled interpreter finds it's various pieces
         // (and to isolate the bundled interpreter from any system Python).
         // Relative to the interpreter binary to make it easier to relocate the bundled Python.
@@ -396,15 +396,11 @@ void PluginRunner::startPlugin()
         ld.prepend(appdir);
         // Reset modified LD_LIBRARY_PATH
         env.insert("LD_LIBRARY_PATH", ld.join(PATH_LIST_DELIM));
-        // Set bundled Linux Python interpreter environment.
-        m_process.setProcessEnvironment(env);
         // If launched by another program (calibre), the new working directory could mess with how the
         // bundled interpreter finds/loads PyQt5. So set it manually to the bundled interpreter's directory.
         m_process.setWorkingDirectory(QDir::toNativeSeparators(QFileInfo(m_enginePath).absolutePath()));
     }
     else {  // Linux native Python settings
-        // Start with system environment.
-        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
         // Remove Sigil's appdir from LD_LIBRARY_PATH if it exists in environment so system Python can run unimpeded.
         QStringList ld = env.value("LD_LIBRARY_PATH", "").split(PATH_LIST_DELIM);
         ld.removeAll(appdir);
@@ -415,11 +411,12 @@ void PluginRunner::startPlugin()
         else {
             env.remove("LD_LIBRARY_PATH");
         }
-        // Set native Linux Python interpreter environment.
-        m_process.setProcessEnvironment(env);
     }
 #endif
 
+    // For plugins to handle mismatches between PyQt5 and PySide6
+    env.insert("SIGIL_QT_RUNTIME_VERSION", QString(qVersion()));
+    m_process.setProcessEnvironment(env);
     m_process.start(executable, args);
     ui.statusLbl->setText(tr("Status: running"));
 
@@ -463,6 +460,7 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
     // before modifying xhtml files make sure they are well formed
     if (!checkIsWellFormed()) {
         ui.statusLbl->setText(tr("Status: No Changes Made"));
+        m_result = "failed";
         return;
     }
 
@@ -472,6 +470,7 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
         if (htmlresources.count() + m_xhtml_net_change < 0) {
             Utility::DisplayStdErrorDialog(tr("Error: Plugin Tried to Remove the Last XHTML file .. aborting changes"));
             ui.statusLbl->setText(tr("Status: No Changes Made"));
+            m_result = "failed";
             return;
         }
     }
@@ -519,11 +518,11 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
     // now make these changes known to Sigil
     m_book->GetFolderKeeper()->ResumeWatchingResources();
 
-#ifdef Q_OS_MAC
+// ifdef  Q_OS_MAC
     // On OS X a new window with the book is opened. The current one's content is not
     // replaced so we don't want to set it as modified if it's an input plugin.
-    if (m_pluginType != "input") {
-#endif
+    // if (m_pluginType != "input") {
+// endif
         if (book_modified) {
             m_bookBrowser->BookContentModified();
             m_bookBrowser->Refresh();
@@ -531,9 +530,9 @@ void PluginRunner::pluginFinished(int exitcode, QProcess::ExitStatus exitstatus)
             // clearMemoryCaches() and updates current tab
             m_mainWindow->ResourcesAddedOrDeletedOrMoved();
         }
-#ifdef Q_OS_MAC
-    }
-#endif
+// ifdef Q_OS_MAC
+    // }
+// endif
     ui.statusLbl->setText(tr("Status:") + " " + m_result);
 
     // Validation plugins we auto close the plugin runner dialog
@@ -601,6 +600,7 @@ void PluginRunner::cancelPlugin()
     ui.textEdit->append(tr("Plugin cancelled"));
     ui.statusLbl->setText(tr("Status: cancelled"));
     ui.cancelButton->setEnabled(false);
+    m_result = "failed";
 }
 
 bool PluginRunner::processResultXML()
@@ -635,17 +635,17 @@ bool PluginRunner::processResultXML()
                 mime =  attr.value("media-type").toString();
                 info << href << id << mime;
                 QString fileinfo = info.join(SEP);
-                if (reader.name() == "deleted") {
+                if (reader.name().compare(QLatin1String("deleted")) == 0) {
                     m_filesToDelete.append(fileinfo);
                     if (mime == "application/xhtml+xml") {
-		        // only count deleting xhtml files that are 
-		        // currently resources (skip unmanifested files)
+                        // only count deleting xhtml files that are 
+                        // currently resources (skip unmanifested files)
                         if (m_xhtmlFiles.contains(href)) {
                             m_xhtml_net_change--;
                             m_xhtmlFiles.remove(href);
                         }
                     }
-                } else if (reader.name() == "added") {
+                } else if (reader.name().compare(QLatin1String("added")) == 0) {
                     m_filesToAdd.append(fileinfo);
                     if (mime == "application/xhtml+xml") {
                         m_xhtml_net_change++;
@@ -693,6 +693,7 @@ bool PluginRunner::processResultXML()
     }
     if (reader.hasError()) {
         Utility::DisplayStdErrorDialog(tr("Error Parsing Result XML:  ") + reader.errorString());
+        m_result = "failed";
         return false;
     }
     return true;
@@ -806,24 +807,24 @@ bool PluginRunner::deleteFiles(const QStringList &files)
         QString id   = fdata[ idField   ];
         QString mime = fdata[ mimeField ];
         // opf and ncx files can not be added or deleted
-	// if they are current resources
+        // if they are current resources
         if (mime == "application/oebps-package+xml") {
-	    if (m_hrefToRes.contains(href)) {
+            if (m_hrefToRes.contains(href)) {
                 continue;
-	    }
+            }
         }
         if (mime == "application/x-dtbncx+xml") {
-	    if (m_hrefToRes.contains(href)) {
-	        QString version = m_book->GetConstOPF()->GetEpubVersion();
-	        NCXResource * ncx_resource = m_book->GetNCX();
-	        if (ncx_resource && version.startsWith('3')) {
-		    m_book->GetOPF()->RemoveNCXOnSpine();
-		    m_book->GetFolderKeeper()->RemoveNCXFromFolder();
-		    ncx_resource->Delete();
+            if (m_hrefToRes.contains(href)) {
+                QString version = m_book->GetConstOPF()->GetEpubVersion();
+                NCXResource * ncx_resource = m_book->GetNCX();
+                if (ncx_resource && version.startsWith('3')) {
+                    m_book->GetOPF()->RemoveNCXOnSpine();
+                    m_book->GetFolderKeeper()->RemoveNCXFromFolder();
+                    ncx_resource->Delete();
                     changes_made = true;
-	        }
+                }
                 continue;
-	    }
+            }
         }
         // under epub3 the nav can not be deleted either
         Resource * nav_resource = m_book->GetConstOPF()->GetNavResource();
@@ -872,7 +873,7 @@ bool PluginRunner::addFiles(const QStringList &files)
             QString epubPath = m_outputDir + "/" + href;
             QFileInfo fi(epubPath);
             ui.statusLbl->setText(tr("Status: Loading") + " " + fi.fileName());
-#ifdef Q_OS_MAC
+#if 0 // was ifdef Q_OS_MAC
             // creating a new MainWindow inside a modal QDialog seems to have issues
             // about mouse pointer location and focus that may cause a segfault in 
             // showModal() -> isBlockingWindow() -> isAncestorOf() when a
@@ -882,21 +883,25 @@ bool PluginRunner::addFiles(const QStringList &files)
             MainWindow *new_window = new MainWindow(epubPath, "", true);
             new_window->show();
             // will this be allowed if PluginRunner is Application Modal
-	    new_window->activateWindow();
+            new_window->activateWindow();
 #else
-            // For Linux and Windows will replace current book
+            // For Linux and Windows and macOS  will replace current book
             // So Throw Up a Dialog to See if they want to proceed
             bool proceed = false;
-            QMessageBox msgBox;
-            msgBox.setIcon(QMessageBox::Warning);
-            msgBox.setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
-            msgBox.setWindowTitle(tr("Input Plugin"));
-            msgBox.setText(tr("Your current book will be completely replaced losing any unsaved changes ...  Are you sure you want to proceed"));
-            QPushButton *yesButton = msgBox.addButton(QMessageBox::Yes);
-            QPushButton *noButton =  msgBox.addButton(QMessageBox::No);
-            msgBox.setDefaultButton(noButton);
-            msgBox.exec();
-            if (msgBox.clickedButton() == yesButton) {
+            if (m_book->IsModified()) {
+                QMessageBox msgBox;
+                msgBox.setIcon(QMessageBox::Warning);
+                msgBox.setWindowFlags(Qt::Window | Qt::WindowStaysOnTopHint);
+                msgBox.setWindowTitle(tr("Input Plugin"));
+                msgBox.setText(tr("Your current book will be completely replaced losing any unsaved changes ...  Are you sure you want to proceed"));
+                QPushButton *yesButton = msgBox.addButton(QMessageBox::Yes);
+                QPushButton *noButton =  msgBox.addButton(QMessageBox::No);
+                msgBox.setDefaultButton(noButton);
+                msgBox.exec();
+                if (msgBox.clickedButton() == yesButton) {
+                    proceed = true;
+                }
+            } else {
                 proceed = true;
             }
             if (proceed) {
@@ -911,20 +916,20 @@ bool PluginRunner::addFiles(const QStringList &files)
             continue;
         }
         if (mime == "application/x-dtbncx+xml") {
-	    // under epub3 you can add an ncx
+            // under epub3 you can add an ncx
             QString version = m_book->GetConstOPF()->GetEpubVersion();
-	    NCXResource * ncx_resource = m_book->GetNCX();
-	    if (!ncx_resource && version.startsWith('3')) {
+            NCXResource * ncx_resource = m_book->GetNCX();
+            if (!ncx_resource && version.startsWith('3')) {
                 QString inpath = m_outputDir + "/" + href;
                 QFileInfo fi(inpath);
                 ui.statusLbl->setText(tr("Status: adding") + " " + fi.fileName());
-	        ncx_resource = m_book->GetFolderKeeper()->AddNCXToFolder(version, href);
-		ncx_resource->SetText(Utility::ReadUnicodeTextFile(inpath));
-		ncx_resource->SaveToDisk();
-		// now add it to the opf with the preferred id
+                ncx_resource = m_book->GetFolderKeeper()->AddNCXToFolder(version, href);
+                ncx_resource->SetText(Utility::ReadUnicodeTextFile(inpath));
+                ncx_resource->SaveToDisk();
+                // now add it to the opf with the preferred id
                 // QString ncx_id = m_book->GetOPF()->AddNCXItem(ncx_resource->GetFullPath(),id);
-		// m_book->GetOPF()->UpdateNCXOnSpine(ncx_id);
-	    }
+                // m_book->GetOPF()->UpdateNCXOnSpine(ncx_id);
+            }
             continue;
         }
 
@@ -1062,7 +1067,7 @@ void PluginRunner::connectSignalsToSlots()
     connect(ui.cancelButton, SIGNAL(clicked()), this, SLOT(cancelPlugin()));
     connect(ui.showButton, SIGNAL(clicked()), this, SLOT(showConsole()));
     connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)), this, SLOT(pluginFinished(int, QProcess::ExitStatus)));
-    connect(&m_process, SIGNAL(error(QProcess::ProcessError)), this, SLOT(processError(QProcess::ProcessError)));
+    connect(&m_process, SIGNAL(errorOccurred(QProcess::ProcessError)), this, SLOT(processError(QProcess::ProcessError)));
     connect(&m_process, SIGNAL(readyReadStandardError()), this, SLOT(processError()));
     connect(&m_process, SIGNAL(readyReadStandardOutput()), this, SLOT(processOutput()));
     connect(ui.okButton, SIGNAL(clicked()), this, SLOT(accept()));
