@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2016-2020  Kevin B. Hendricks, Stratford, ON
+**  Copyright (C) 2016-2021  Kevin B. Hendricks, Stratford, ON
 **  Copyright (C) 2016-2020  Doug Massay
 **  Copyright (C) 2011-2013  John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012-2013  Grant Drake
@@ -27,7 +27,9 @@
 #include <QtWidgets/QListWidget>
 #include <QtGui/QPainter>
 #include <QtWidgets/QStyledItemDelegate>
-#include <QtWebEngineWidgets/QWebEngineSettings>
+#include <QtWebEngineWidgets>
+#include <QtWebEngineCore>
+#include <QWebEngineSettings>
 #include <QFontDialog>
 #include <QFileInfo>
 
@@ -82,13 +84,18 @@ AppearanceWidget::AppearanceWidget()
     m_isHighDPIComboEnabled(true)
 {
 
-#ifdef Q_OS_MAC
+#if defined(Q_OS_MAC) || QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     // Disable the HighDPI combobox on Mac
     // Effectively an isMacOS runtime check
+    // Also needed if Qt >= 6.0.0
     m_isHighDPIComboEnabled = false;
 #endif
 
     ui.setupUi(this);
+#ifdef Q_OS_MAC
+    // according to macos user interface guidelines native apps would use TicksBelow
+    ui.iconSizeSlider->setTickPosition(QSlider::TicksBelow);
+#endif
     ui.Default->setEnabled(true);
     ui.Fluent->setEnabled(true);
     ui.Material->setEnabled(true);
@@ -125,6 +132,7 @@ AppearanceWidget::AppearanceWidget()
     ui.dragTweakSpinBox->setMaximum(20);
     // The Drag start-distance setting is unused/unnecessary on Mac
     ui.dragTweakSpinBox->setEnabled(m_isHighDPIComboEnabled);
+    ui.chkHightlightTags->setToolTip("<p>" + tr("Highlight matching tags in Code View when cursor is inside tags."));
     m_codeViewAppearance = readSettings();
     loadCodeViewColorsList(m_codeViewAppearance);
     m_uiFontResetFlag = false;
@@ -145,7 +153,7 @@ PreferencesWidget::ResultActions AppearanceWidget::saveSettings()
         icon_theme = "material";
     } else if (ui.Custom->isEnabled() && ui.Custom->isChecked()) {
         icon_theme = "custom";
-    }	
+    }
     settings.setUIIconTheme(icon_theme);
     // Don't try to get the index of a disabled combobox
     if (m_isHighDPIComboEnabled) {
@@ -188,13 +196,18 @@ PreferencesWidget::ResultActions AppearanceWidget::saveSettings()
             settings.setCodeViewAppearance(codeViewAppearance);
         }
     }
+    settings.setHighlightOpenCloseTags(ui.chkHightlightTags->isChecked());
     SettingsStore::SpecialCharacterAppearance specialCharacterAppearance;
     specialCharacterAppearance.font_family = ui.cbSpecialCharacterFont->currentText();
     specialCharacterAppearance.font_size   = ui.specialCharacterFontSizeSpin->value();
     settings.setSpecialCharacterAppearance(specialCharacterAppearance);
     settings.setMainMenuIconSize(double(ui.iconSizeSlider->value())/10);
     // PV settings can be globally changed and will take effect immediately
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QWebEngineSettings *web_settings = QWebEngineSettings::defaultSettings();
+#else
+    QWebEngineSettings *web_settings = QWebEngineProfile::defaultProfile()->settings();
+#endif
     web_settings->setFontSize(QWebEngineSettings::DefaultFontSize,   PVAppearance.font_size);
     web_settings->setFontFamily(QWebEngineSettings::StandardFont,    PVAppearance.font_family_standard);
     web_settings->setFontFamily(QWebEngineSettings::SerifFont,       PVAppearance.font_family_serif);
@@ -265,12 +278,12 @@ SettingsStore::CodeViewAppearance AppearanceWidget::readSettings()
     QString icon_theme = settings.uiIconTheme();
     m_currentIconTheme = icon_theme;
     if (ui.Custom->isEnabled()) {
-	ui.Custom->setChecked(icon_theme == "custom");
+        ui.Custom->setChecked(icon_theme == "custom");
     } else {
-	ui.Custom->setChecked(false);
-	if (icon_theme == "custom") {
-	    icon_theme = "main";
-	}
+        ui.Custom->setChecked(false);
+        if (icon_theme == "custom") {
+            icon_theme = "main";
+        }
     }
     ui.Default->setChecked(icon_theme == "main");
     ui.Fluent->setChecked(icon_theme == "fluent");
@@ -300,6 +313,7 @@ SettingsStore::CodeViewAppearance AppearanceWidget::readSettings()
         codeViewAppearance = settings.codeViewAppearance();
         m_wasDark = false;
     }
+    ui.chkHightlightTags->setChecked(settings.highlightOpenCloseTags() == true);
     SettingsStore::SpecialCharacterAppearance specialCharacterAppearance = settings.specialCharacterAppearance();
     loadComboValueOrDefault(ui.cbPreviewFontStandard,  PVAppearance.font_family_standard,    "Arial");
     loadComboValueOrDefault(ui.cbPreviewFontSerif,     PVAppearance.font_family_serif,       "Times New Roman");
