@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2019-2020 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2019-2021 Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2011      John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012      Dave Heiland
 **
@@ -35,7 +35,8 @@
 
 GeneralSettingsWidget::GeneralSettingsWidget()
     :
-    m_refreshClipboardHistoryLimit(false)
+    m_refreshClipboardHistoryLimit(false),
+    m_disable_gpu(false)
 {
     ui.setupUi(this);
     readSettings();
@@ -93,12 +94,17 @@ PreferencesWidget::ResultActions GeneralSettingsWidget::saveSettings()
          new_temp_folder_home = ui.lineEdit->text();
     }
 
+    bool new_disable_gpu = false;
+    if (ui.DisableGPU->isChecked()) {
+        new_disable_gpu = true;
+    }
+
     QString new_xeditor_path = "";
     if (!ui.lineEdit7->text().isEmpty()) {
          QString xeditorpath = ui.lineEdit7->text();
-	 if (QFileInfo(xeditorpath).exists()) {
-	     new_xeditor_path = xeditorpath;
-	 }
+         if (QFileInfo(xeditorpath).exists()) {
+             new_xeditor_path = xeditorpath;
+         }
     }
 
     SettingsStore settings;
@@ -110,8 +116,12 @@ PreferencesWidget::ResultActions GeneralSettingsWidget::saveSettings()
     settings.setJavascriptOn(new_javascript_on_level);
     settings.setClipboardHistoryLimit(int(ui.clipLimitSpin->value()));
     settings.setTempFolderHome(new_temp_folder_home);
+    settings.setDisableGPU(new_disable_gpu);
+    // if you change this setting you need to restart sigil to see the change
+    if (new_disable_gpu != m_disable_gpu) {
+        results = results | PreferencesWidget::ResultAction_RestartSigil;
+    }
     settings.setExternalXEditorPath(new_xeditor_path);
-
     if (m_refreshClipboardHistoryLimit) {
         results = results | PreferencesWidget::ResultAction_RefreshClipHistoryLimit;
     }
@@ -143,6 +153,8 @@ void GeneralSettingsWidget::readSettings()
     ui.clipLimitSpin->setValue(int(settings.clipboardHistoryLimit()));
     QString temp_folder_home = settings.tempFolderHome();
     ui.lineEdit->setText(temp_folder_home);
+    m_disable_gpu = settings.disableGPU();
+    ui.DisableGPU->setChecked(m_disable_gpu);
     QString xeditor_path = settings.externalXEditorPath();
     ui.lineEdit7->setText(xeditor_path);
 }
@@ -178,10 +190,10 @@ void GeneralSettingsWidget::setXEditorPath()
 
     // Qt Bug - you must use a native FileDialog on macOS otherwise it treats .app as a normal directory
     QString xeditorPath = QFileDialog::getOpenFileName(this,
-						       QObject::tr("Select External Xhtml Editor"),
-						       LAST_LOCATION,
-						       NAME_FILTER,
-						       0,
+                                                       QObject::tr("Select External Xhtml Editor"),
+                                                       LAST_LOCATION,
+                                                       NAME_FILTER,
+                                                       0,
                                                        options);
     ui.lineEdit7->setText(xeditorPath);
 }
@@ -214,9 +226,9 @@ void GeneralSettingsWidget::setTempFolder()
 #endif
 
     QString name = QFileDialog::getExistingDirectory(this, 
-						     tr("Select Folder for Temporary Files"),
-						     QString(),
-						     options);
+                                                     tr("Select Folder for Temporary Files"),
+                                                     QString(),
+                                                     options);
     if (name.isEmpty()) {
         return;
     }
