@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2020 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2022 Kevin B. Hendricks, Stratford Ontario Canada
 **  Copyright (C) 2012 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012 Dave Heiland
 **  Copyright (C) 2012 Grant Drake
@@ -28,7 +28,7 @@
 
 #include <QtWidgets/QDialog>
 #include <QtGui/QStandardItemModel>
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QMenu>
 #include <QPointer>
 
@@ -38,6 +38,8 @@
 
 #include "ui_SearchEditor.h"
 
+class SearchEditorItemDelegate;
+
 /**
  * The editor used to create and modify saved searches
  */
@@ -47,20 +49,33 @@ class SearchEditor : public QDialog
 
 public:
     SearchEditor(QWidget *parent);
+    ~SearchEditor();
+
     void ForceClose();
 
+    void RecordEntryAsCompleted(SearchEditorModel::searchEntry* entry);
+    QList<SearchEditorModel::searchEntry*> GetCurrentEntries();
+    int GetCurrentEntriesCount() { return m_CurrentSearchEntries.count(); }
+
 public slots:
+
     QStandardItem *AddEntry(bool is_group = false, SearchEditorModel::searchEntry *search_entry = NULL, bool insert_after = true);
 
     void ShowMessage(const QString &message);
 
+    void SelectionChanged();
+
+    void SetCurrentEntriesFromFullName(const QString& name);
+
 signals:
+
     void LoadSelectedSearchRequest(SearchEditorModel::searchEntry *search_entry);
-    void FindSelectedSearchRequest(QList<SearchEditorModel::searchEntry *> search_entries);
-    void ReplaceCurrentSelectedSearchRequest(QList<SearchEditorModel::searchEntry *> search_entries);
-    void ReplaceSelectedSearchRequest(QList<SearchEditorModel::searchEntry *> search_entries);
-    void CountAllSelectedSearchRequest(QList<SearchEditorModel::searchEntry *> search_entries);
-    void ReplaceAllSelectedSearchRequest(QList<SearchEditorModel::searchEntry *> search_entries);
+    void FindSelectedSearchRequest();
+    void ReplaceCurrentSelectedSearchRequest();
+    void ReplaceSelectedSearchRequest();
+    void CountAllSelectedSearchRequest();
+    void ReplaceAllSelectedSearchRequest();
+    void RestartSearch();
 
     void ShowStatusMessageRequest(const QString &message);
 
@@ -84,7 +99,8 @@ private slots:
     void ExportAll();
     void CollapseAll();
     void ExpandAll();
-
+    void FillControls();
+    
     void Apply();
     bool Save();
 
@@ -109,6 +125,7 @@ private slots:
     void ModelItemDropped(const QModelIndex &index);
 
 private:
+
     bool MaybeSaveDialogSaysProceed(bool is_forced);
     void MoveVertical(bool move_down);
     void MoveHorizontal(bool move_left);
@@ -121,13 +138,16 @@ private:
 
     SearchEditorModel::searchEntry *GetSelectedEntry(bool show_warning = true);
     QList<SearchEditorModel::searchEntry *> GetSelectedEntries();
-
+    
     QList<QStandardItem *> GetSelectedItems();
 
     bool ItemsAreUnique(QList<QStandardItem *> items);
 
     bool SaveData(QList<SearchEditorModel::searchEntry *> entries = QList<SearchEditorModel::searchEntry *>() , QString filename = QString());
 
+    bool SaveTextData(QList<SearchEditorModel::searchEntry *> entries = QList<SearchEditorModel::searchEntry *>() ,
+                      QString filename = QString(), QChar sep=QChar(9));
+
     bool FilterEntries(const QString &text, QStandardItem *item = NULL);
     bool SelectFirstVisibleNonGroup(QStandardItem *item);
 
@@ -152,6 +172,7 @@ private:
     QAction *m_ExportAll;
     QAction *m_CollapseAll;
     QAction *m_ExpandAll;
+    QAction *m_FillIn;
 
     SearchEditorModel *m_SearchEditorModel;
 
@@ -159,8 +180,16 @@ private:
 
     QPointer<QMenu> m_ContextMenu;
 
+    // stores result of cut/copy for later paste
     QList<SearchEditorModel::searchEntry *> m_SavedSearchEntries;
 
+    // List of the remaining currently selected Entries updated  to remember state
+    QList<SearchEditorModel::searchEntry *> m_CurrentSearchEntries;
+
+    SearchEditorModel::searchEntry * m_SearchToLoad;
+
+    SearchEditorItemDelegate * m_CntrlDelegate;
+
     Ui::SearchEditor ui;
 };
 
