@@ -20,37 +20,42 @@
 **
 *************************************************************************/
 
-#include <QtCore/QFileInfo>
+#include <QString>
+#include <QImage>
+#include <QToolButton>
+#include <QFileInfo>
+#include <QHBoxLayout>
+#include <QVBoxLayout>
 #include <QApplication>
 #include <QGuiApplication>
 #include <QtWidgets/QLayout>
-#include <QtWebEngineWidgets/QWebEngineView>
-#include <QtWebEngineWidgets/QWebEngineSettings>
-#include <QtWebEngineWidgets/QWebEngineProfile>
 
-#include "MainUI/MainWindow.h"
 #include "ResourceObjects/ImageResource.h"
 #include "ViewEditors/SimplePage.h"
 #include "Misc/Utility.h"
-#include "sigil_constants.h"
+#include "MainUI/MainApplication.h"
+#include "Widgets/ImageView.h"
 #include "Dialogs/ViewImage.h"
 
 static QString SETTINGS_GROUP = "view_image";
 
 ViewImage::ViewImage(QWidget *parent)
     :
-    QDialog(parent)
+    QDialog(parent),
+    m_iv(new ImageView(this)),
+    m_bp(new QToolButton(this)),
+    m_layout(new QVBoxLayout(this))
 {
-    ui.setupUi(this);
-    ui.webView->setPage(new SimplePage(ui.webView));
-    ui.webView->setContextMenuPolicy(Qt::NoContextMenu);
-    ui.webView->setFocusPolicy(Qt::NoFocus);
-    ui.webView->setAcceptDrops(false);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
-    ui.webView->page()->settings()->setAttribute(QWebEngineSettings::ShowScrollBars,false);
-#endif
-
+    m_layout->addWidget(m_iv);
+    m_bp->setToolTip(tr("Close this window"));
+    m_bp->setText(tr("Done"));
+    m_bp->setToolButtonStyle(Qt::ToolButtonTextOnly);
+    QHBoxLayout* hl = new QHBoxLayout();
+    hl->addStretch(0);
+    hl->addWidget(m_bp);
+    m_layout->addLayout(hl);
     ReadSettings();
+    ConnectSignalsToSlots();
 }
 
 ViewImage::~ViewImage()
@@ -58,30 +63,32 @@ ViewImage::~ViewImage()
     WriteSettings();
 }
 
+QSize ViewImage::sizeHint()
+{
+    return QSize(450,450);
+}
+
 void ViewImage::ShowImage(QString path)
 {
-    ui.webView->page()->profile()->clearHttpCache();
-    const QUrl resourceUrl = QUrl::fromLocalFile(path);
-    QString html = IMAGE_HTML_BASE_PREVIEW.arg(resourceUrl.toString());
-    if (Utility::IsDarkMode()) {
-	html = Utility::AddDarkCSS(html);
-    }
-    ui.webView->page()->setBackgroundColor(Utility::WebViewBackgroundColor());
-    ui.webView->setHtml(html, resourceUrl);
+    m_iv->ShowImage(path);
     QApplication::processEvents();
 }
 
+void ViewImage::ReloadViewer()
+{
+    m_iv->ReloadViewer();
+}
+
 void ViewImage::ReadSettings()
 {
     SettingsStore settings;
     settings.beginGroup(SETTINGS_GROUP);
-    // The size of the window and it's full screen status
     QByteArray geometry = settings.value("geometry").toByteArray();
-
     if (!geometry.isNull()) {
         restoreGeometry(geometry);
+    } else {
+        resize(sizeHint());
     }
-
     settings.endGroup();
 }
 
@@ -89,8 +96,15 @@ void ViewImage::WriteSettings()
 {
     SettingsStore settings;
     settings.beginGroup(SETTINGS_GROUP);
-    // The size of the window and it's full screen status
     settings.setValue("geometry", saveGeometry());
     settings.endGroup();
 }
 
+void ViewImage::ConnectSignalsToSlots()
+{
+#ifdef Q_OS_MAC
+    MainApplication *mainApplication = qobject_cast<MainApplication *>(qApp);
+    connect(mainApplication, SIGNAL(applicationPaletteChanged()), this, SLOT(ReloadViewer()));
+#endif
+    connect(m_bp, SIGNAL(clicked()), this, SLOT(accept()));
+}
