@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford, Ontario Canada
+**  Copyright (C) 2015-2022 Kevin B. Hendricks, Stratford, Ontario Canada
 **  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
 **
 **  This file is part of Sigil.
@@ -20,14 +20,15 @@
 **
 *************************************************************************/
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QSignalMapper>
-#include <QtWidgets/QFileDialog>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QMessageBox>
-#include <QtWidgets/QTreeView>
-#include <QtWidgets/QProgressDialog>
-#include <QtWidgets/QScrollBar>
+#include <QFileInfo>
+#include <QSignalMapper>
+#include <QFileDialog>
+#include <QMenu>
+#include <QMessageBox>
+#include <QTreeView>
+#include <QProgressDialog>
+#include <QScrollBar>
+#include <QVariant>
 #include <QDebug>
 
 #include "BookManipulation/Book.h"
@@ -57,9 +58,16 @@
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
-
 #define DBG if(0)
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    static const QVariant QVINVALID = QVariant(QVariant::Invalid);
+#else 
+    #include <QMetaType>
+    static const QVariant QVINVALID = QVariant(QMetaType(QMetaType::UnknownType));
+#endif
+
+
 static const QString SETTINGS_GROUP = "bookbrowser";
 static const QString OPF_NCX_EDIT_WARNING_KEY = SETTINGS_GROUP + "-opfncx-warning";
 static const int COLUMN_INDENTATION = 10;
@@ -361,6 +369,12 @@ QList <Resource *> BookBrowser::AllCSSResources()
     return m_OPFModel->GetResourceListInFolder(Resource::CSSResourceType);
 }
 
+QList <Resource *> BookBrowser::AllJSResources()
+{
+    QStringList mtypes = QStringList() << "text/javascript" << "application/javascript" << "application/ecmascript";
+    return m_Book->GetFolderKeeper()->GetResourceListByMediaTypes(mtypes);
+}
+
 QList <Resource *> BookBrowser::ValidSelectedResources(Resource::ResourceType resource_type)
 {
     QList <Resource *> resources = ValidSelectedResources();
@@ -386,7 +400,7 @@ int BookBrowser::AllSelectedItemCount()
     const QString &identifier = item->data().toString();
 
     // If folder item included, multiple selection is invalid                                                                              
-    if (identifier == NULL) {
+    if (identifier.isEmpty()) {
       return -1;
     }
 
@@ -482,7 +496,7 @@ int BookBrowser::ValidSelectedItemCount()
         const QString &identifier = item->data().toString();
 
         // If folder item included, multiple selection is invalid
-        if (identifier == NULL) {
+        if (identifier.isEmpty()) {
             return -1;
         }
 
@@ -517,6 +531,9 @@ void BookBrowser::AddNew()
         AddNewHTML();
     } else if (m_LastContextMenuType == Resource::CSSResourceType) {
         AddNewCSS();
+    } else if (m_LastContextMenuType == Resource::MiscTextResourceType ||
+               m_LastContextMenuType == Resource::GenericResourceType) {
+        AddNewJS();
     } else if (m_LastContextMenuType == Resource::ImageResourceType) {
         AddNewSVG();
     }
@@ -536,7 +553,8 @@ void BookBrowser::CopyHTML()
 
     HTMLResource *current_html_resource = qobject_cast<HTMLResource *>(current_resource);
     // Create an empty file
-    HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(current_html_resource, destfolder);
+    // was HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(current_html_resource, destfolder);
+    HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(destfolder);
     m_Book->MoveResourceAfter(new_html_resource, current_html_resource);
     // Copy the text from the current file
     new_html_resource->SetText(current_html_resource->GetText());
@@ -552,11 +570,13 @@ void BookBrowser::AddNewHTML()
 {
     Resource *current_resource = GetCurrentResource();
     HTMLResource *current_html_resource = qobject_cast<HTMLResource *>(current_resource);
+
     QString destfolder = "\\";
     if (current_html_resource) {
         destfolder = Utility::startingDir(current_html_resource->GetRelativePath());
     }
-    HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(current_html_resource, destfolder);
+    // was HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(current_html_resource, destfolder);
+    HTMLResource *new_html_resource = m_Book->CreateEmptyHTMLFile(destfolder);
 
     if ((current_resource != NULL) && (current_html_resource != NULL)) {
         m_Book->MoveResourceAfter(new_html_resource, current_html_resource);
@@ -598,6 +618,24 @@ void BookBrowser::AddNewCSS()
     Refresh();
 }
 
+void BookBrowser::AddNewJS()
+{
+    QString version = m_Book->GetConstOPF()->GetEpubVersion();
+    if (version.startsWith('2')) {
+        QMessageBox::StandardButton button_pressed;
+        button_pressed = QMessageBox::warning(this, tr("Sigil"),tr("Javascript is not supported on epub2.")
+                                              ,QMessageBox::Ok);
+        return;
+    }
+
+    MiscTextResource *new_resource = m_Book->CreateEmptyJSFile();
+    new_resource->SaveToDisk();
+    // Open the new file in a tab
+    emit ResourceActivated(new_resource);
+    emit BookContentModified();
+    Refresh();
+}
+
 void BookBrowser::AddNewSVG()
 {
     SVGResource *new_resource = m_Book->CreateEmptySVGFile();
@@ -1625,6 +1663,23 @@ void BookBrowser::LinkStylesheets()
     emit LinkStylesheetsToResourcesRequest(ValidSelectedResources(Resource::HTMLResourceType));
 }
 
+void BookBrowser::LinkJavascripts()
+{
+    QList <Resource *> resources = ValidSelectedResources();
+
+    if (resources.isEmpty()) {
+        return;
+    }
+
+    Resource::ResourceType resource_type = resources.first()->Type();
+
+    if (resource_type != Resource::HTMLResourceType) {
+        return;
+    }
+
+    emit LinkJavascriptsToResourcesRequest(ValidSelectedResources(Resource::HTMLResourceType));
+}
+
 
 void BookBrowser::NoObfuscationMethod()
 {
@@ -1727,6 +1782,7 @@ void BookBrowser::CreateContextMenuActions()
     m_SelectAll               = new QAction(tr("Select All"),            this);
     m_AddNewHTML              = new QAction(tr("Add Blank HTML File"),   this);
     m_AddNewCSS               = new QAction(tr("Add Blank Stylesheet"),  this);
+    m_AddNewJS                = new QAction(tr("Add Blank Javascript"),  this);
     m_AddNewSVG               = new QAction(tr("Add Blank SVG Image"),   this);
     m_AddExisting             = new QAction(tr("Add Existing Files..."), this);
     m_CopyHTML                = new QAction(tr("Add Copy"),              this);
@@ -1743,6 +1799,7 @@ void BookBrowser::CreateContextMenuActions()
     m_SortHTML                = new QAction(tr("Sort") + "...",          this);
     m_RenumberTOC             = new QAction(tr("Renumber TOC Entries"),  this);
     m_LinkStylesheets         = new QAction(tr("Link Stylesheets..."),   this);
+    m_LinkJavascripts         = new QAction(tr("Link Javascripts..."),   this);
     m_AddSemantics            = new QAction(tr("Add Semantics..."),      this);
     m_ValidateWithW3C         = new QAction(tr("Validate with W3C"),     this);
     m_OpenWith                = new QAction(tr("Open With") + "...",     this);
@@ -1756,22 +1813,24 @@ void BookBrowser::CreateContextMenuActions()
     m_NoObfuscationMethod    ->setCheckable(true);
     m_AdobesObfuscationMethod->setCheckable(true);
     m_IdpfsObfuscationMethod ->setCheckable(true);
-    m_CopyHTML->setShortcut(QKeySequence(Qt::CTRL + Qt::SHIFT + Qt::Key_Y));
+    m_CopyHTML->setShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Y));
     sm->registerAction(this, m_CopyHTML, "MainWindow.BookBrowser.CopyHTML");
     m_Delete->setShortcut(QKeySequence::Delete);
-    m_Merge->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_M));
+    m_Merge->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_M));
     m_Merge->setToolTip(tr("Merge with previous file, or merge multiple files into one."));
     sm->registerAction(this, m_Merge, "MainWindow.BookBrowser.Merge");
-    m_Rename->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_R));
+    m_Rename->setShortcut(QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_R));
     m_Rename->setToolTip(tr("Rename selected file(s)"));
     sm->registerAction(this, m_Rename, "MainWindow.BookBrowser.Rename");
     m_RERename->setToolTip(tr("Use Regular Expressions to Rename selected file(s)"));
     sm->registerAction(this, m_RERename, "MainWindow.BookBrowser.RERename");
-    // m_Move->setShortcut(QKeySequence(Qt::CTRL + Qt::ALT + Qt::Key_R));
+    // m_Move->setShortcut(QKeySequence(Qt::CTRL | Qt::ALT | Qt::Key_R));
     m_Move->setToolTip(tr("Move selected file(s) to a new folder"));
     sm->registerAction(this, m_Move, "MainWindow.BookBrowser.Move");
     m_LinkStylesheets->setToolTip(tr("Link Stylesheets to selected file(s)."));
     sm->registerAction(this, m_LinkStylesheets, "MainWindow.BookBrowser.LinkStylesheets");
+    m_LinkJavascripts->setToolTip(tr("Link Javascripts to selected file(s)."));
+    sm->registerAction(this, m_LinkJavascripts, "MainWindow.BookBrowser.LinkJavascripts");
     m_AddSemantics->setToolTip(tr("Add Semantics to selected file(s)."));
     sm->registerAction(this, m_AddSemantics, "MainWindow.BookBrowser.AddSemantics");
     // Has to be added to the book browser itself as well
@@ -1783,6 +1842,7 @@ void BookBrowser::CreateContextMenuActions()
     addAction(m_RERename);
     addAction(m_Move);
     addAction(m_LinkStylesheets);
+    addAction(m_LinkJavascripts);
     addAction(m_AddSemantics);
 }
 
@@ -1829,6 +1889,8 @@ bool BookBrowser::SuccessfullySetupContextMenu(const QPoint &point)
             m_SortHTML->setEnabled(item_count > 1);
             m_ContextMenu->addAction(m_LinkStylesheets);
             m_LinkStylesheets->setEnabled(AllCSSResources().count() > 0);
+            m_ContextMenu->addAction(m_LinkJavascripts);
+            m_LinkJavascripts->setEnabled(AllJSResources().count() > 0);
             m_ContextMenu->addAction(m_AddSemantics);
         }
 
@@ -1862,11 +1924,11 @@ bool BookBrowser::SuccessfullySetupContextMenu(const QPoint &point)
             const QStringList editor_paths = OpenExternally::editorsForResourceType(resource->Type());
             const QStringList editor_names = OpenExternally::editorDescriptionsForResourceType(resource->Type());
             if (editor_paths.isEmpty()) {
-                m_OpenWithEditor0->setData(QVariant::Invalid);
-                m_OpenWithEditor1->setData(QVariant::Invalid);
-                m_OpenWithEditor2->setData(QVariant::Invalid);
-                m_OpenWithEditor3->setData(QVariant::Invalid);
-                m_OpenWithEditor4->setData(QVariant::Invalid);
+                m_OpenWithEditor0->setData(QVINVALID);
+                m_OpenWithEditor1->setData(QVINVALID);
+                m_OpenWithEditor2->setData(QVINVALID);
+                m_OpenWithEditor3->setData(QVINVALID);
+                m_OpenWithEditor4->setData(QVINVALID);
                 m_OpenWith->setText(tr("Open With") + "...");
                 m_ContextMenu->addAction(m_OpenWith);
             } else {
@@ -1879,7 +1941,7 @@ bool BookBrowser::SuccessfullySetupContextMenu(const QPoint &point)
                     if (k==3) oeaction = m_OpenWithEditor3;
                     if (k==4) oeaction = m_OpenWithEditor4;
                     if (oeaction) {
-                        oeaction->setData(QVariant::Invalid);
+                        oeaction->setData(QVINVALID);
                         oeaction->setText("");
                         oeaction->setEnabled(false);
                         oeaction->setVisible(false);
@@ -1925,6 +1987,12 @@ bool BookBrowser::SuccessfullySetupContextMenu(const QPoint &point)
         m_ContextMenu->addAction(m_AddNewCSS);
         m_ContextMenu->addAction(m_CopyCSS);
         m_CopyCSS->setEnabled(item_count == 1);
+    } else if (m_LastContextMenuType == Resource::MiscTextResourceType ||
+               m_LastContextMenuType == Resource::GenericResourceType) {
+        QString version = m_Book->GetConstOPF()->GetEpubVersion();
+        if (version.startsWith('3')) {
+            m_ContextMenu->addAction(m_AddNewJS);
+        }
     } else if (m_LastContextMenuType == Resource::ImageResourceType || m_LastContextMenuType == Resource::SVGResourceType) {
         m_ContextMenu->addAction(m_AddNewSVG);
     }
@@ -2011,6 +2079,7 @@ void BookBrowser::ConnectSignalsToSlots()
     connect(m_RenumberTOC,             SIGNAL(triggered()), this, SLOT(RenumberTOC()));
     connect(m_SortHTML,                SIGNAL(triggered()), this, SLOT(SortHTML()));
     connect(m_AddNewCSS,               SIGNAL(triggered()), this, SLOT(AddNewCSS()));
+    connect(m_AddNewJS,                SIGNAL(triggered()), this, SLOT(AddNewJS()));
     connect(m_AddNewSVG,               SIGNAL(triggered()), this, SLOT(AddNewSVG()));
     connect(m_AddExisting,             SIGNAL(triggered()), this, SLOT(AddExisting()));
     connect(m_Rename,                  SIGNAL(triggered()), this, SLOT(Rename()));
@@ -2020,6 +2089,7 @@ void BookBrowser::ConnectSignalsToSlots()
     connect(m_CoverImage,              SIGNAL(triggered()), this, SLOT(SetCoverImage()));
     connect(m_Merge,                   SIGNAL(triggered()), this, SLOT(Merge()));
     connect(m_LinkStylesheets,         SIGNAL(triggered()), this, SLOT(LinkStylesheets()));
+    connect(m_LinkJavascripts,         SIGNAL(triggered()), this, SLOT(LinkJavascripts()));
     connect(m_AddSemantics,            SIGNAL(triggered()), this, SLOT(AddSemanticCode()));
     connect(m_SaveAs,                  SIGNAL(triggered()), this, SLOT(SaveAs()));
     connect(m_ValidateWithW3C,         SIGNAL(triggered()), this, SLOT(ValidateStylesheetWithW3C()));
@@ -2034,7 +2104,11 @@ void BookBrowser::ConnectSignalsToSlots()
     m_openWithMapper->setMapping(m_OpenWithEditor3, 3);
     connect(m_OpenWithEditor4, SIGNAL(triggered()),  m_openWithMapper, SLOT(map()));
     m_openWithMapper->setMapping(m_OpenWithEditor4, 4);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_openWithMapper, SIGNAL(mapped(int)), this, SLOT(OpenWithEditor(int)));
+#else
+    connect(m_openWithMapper, SIGNAL(mappedInt(int)), this, SLOT(OpenWithEditor(int)));
+#endif
     connect(m_AdobesObfuscationMethod, SIGNAL(triggered()), this, SLOT(AdobesObfuscationMethod()));
     connect(m_IdpfsObfuscationMethod,  SIGNAL(triggered()), this, SLOT(IdpfsObfuscationMethod()));
     connect(m_NoObfuscationMethod,     SIGNAL(triggered()), this, SLOT(NoObfuscationMethod()));
