@@ -48,6 +48,7 @@
 #include "MiscEditors/SearchEditorModel.h"
 #include "Tabs/ContentTab.h"
 #include "ViewEditors/ElementIndex.h"
+#include "Dialogs/SearchEditor.h"
 
 const int MAX_RECENT_FILES = 5;
 const int STATUSBAR_MSG_DISPLAY_TIME = 7000;
@@ -110,6 +111,10 @@ public:
 
     ~MainWindow();
 
+    // routines to help Find and Replace exchange info with the SearchEditor
+    QList<SearchEditorModel::searchEntry*> SearchEditorGetCurrentEntries();
+    void SearchEditorRecordEntryAsCompleted(SearchEditorModel::searchEntry* entry);
+
     void maybe_fixup_dockwidget_geometry(QDockWidget * widget);
 
     // returns true if MainWindow is Maximized or is FullScreen
@@ -145,12 +150,15 @@ public:
      *
      * @return List of valid selected HTML resources
      */
+    QList <Resource *> GetBookBrowserSelectedResources();
     QList <Resource *> GetValidSelectedHTMLResources();
     QList <Resource *> GetValidSelectedCSSResources();
 
     QList <Resource *> GetTabbedHTMLResources();
     QList <Resource *> GetTabbedCSSResources();
 
+    bool RenameClassInHtml(const QString& oldname, const QString& newname);
+
     /**
      * Returns a list of all HTML resources in book browser order
      *
@@ -215,9 +223,14 @@ public:
 
     QString GetMathJaxFolder() { return m_mathjaxfolder; };
 
+    bool UsingAutomate() { return m_UsingAutomate; }
+
+    QString AutomatePluginParameter() { return m_AutomatePluginParameter; }
 
 public slots:
 
+    bool Automate(const QStringList &commands);
+
     void OpenUrl(const QUrl &url);
 
     void ScrollCVToFragment(const QString &fragment);
@@ -239,11 +252,11 @@ public slots:
                                         const QUrl &fragment = QUrl(),
                                         bool precede_current_tab = false);
 
-    void UpdateManifestProperties();
+    bool UpdateManifestProperties();
 
-    void GenerateNCXGuideFromNav();
+    bool GenerateNCXGuideFromNav();
 
-    void RemoveNCXGuideFromEpub3();
+    bool RemoveNCXGuideFromEpub3();
 
     void CreateIndex();
 
@@ -253,12 +266,22 @@ public slots:
 
     void launchExternalXEditor();
 
-    void RepoCommit();
+    bool RepoCommit();
     void RepoCheckout(QString bookid="", QString destpath="", QString filename="", bool loadnow=true);
     void RepoDiff(QString bookid="");
     void RepoManage();
 
-    void StandardizeEpub();
+    void RunAutomate1();
+    void RunAutomate2();
+    void RunAutomate3();
+    void RunAutomate(const QString &automatefile);
+
+    void EditAutomate1();
+    void EditAutomate2();
+    void EditAutomate3();
+    void EditAutomate(const QString &automatefile);
+    
+    bool StandardizeEpub();
 
     void CreateEpubLayout();
 
@@ -291,7 +314,7 @@ private slots:
 
     void RestoreLastNormalGeometry();
 
-    void AddCover();
+    bool AddCover();
 
 
     /**
@@ -365,8 +388,8 @@ private slots:
 
     bool DeleteCSSStyles(const QString &filename, QList<CSSInfo::CSSSelector *> css_selectors);
 
-    void DeleteUnusedMedia();
-    void DeleteUnusedStyles();
+    bool DeleteUnusedMedia(bool in_automate = false);
+    bool DeleteUnusedStyles(bool in_automate = false);
 
     void InsertFileDialog();
 
@@ -453,9 +476,11 @@ private slots:
     /**
      * Implements Validate Epub action functionality.
      */
-    void WellFormedCheckEpub();
+    bool WellFormedCheckEpub();
 
-    void ValidateStylesheetsWithW3C();
+    bool ValidateStylesheetsWithW3C();
+
+    bool ReformatAllStylesheets(bool multiple_line_format);
 
     bool CharLessThan(const QChar &s1, const QChar &s2);
 
@@ -578,15 +603,15 @@ private slots:
     /**
      * Creates new section/XHTML documents.
      */
-    void SplitOnSGFSectionMarkers();
+    bool SplitOnSGFSectionMarkers();
 
     void SetAutoSpellCheck(bool new_state);
 
     /**
      * Reformats all the book's html resources using Book.cpp's ReformatAllHTML() function.
      */
-    void MendPrettifyHTML();
-    void MendHTML();
+    bool MendPrettifyHTML();
+    bool MendHTML();
 
     void ClearIgnoredWords();
 
@@ -596,6 +621,8 @@ private slots:
 
     void LinkStylesheetsToResources(QList <Resource *> resources);
 
+    void LinkJavascriptsToResources(QList <Resource *> resources);
+
     void ResourceUpdatedFromDisk(Resource *resource);
 
     void UpdateWord(QString old_word, QString new_word);
@@ -611,11 +638,15 @@ private slots:
      */
     QStringList GetStylesheetsAlreadyLinked(Resource *resource);
 
+    QList<std::pair<QString, bool>> GetJavascriptsMap(QList<Resource *> resources);
+    QStringList GetJavascriptsAlreadyLinked(Resource *resource);
+
+
     void RemoveResources(QList<Resource *> resources = QList<Resource *>());
 
-    void GenerateToc();
+    bool GenerateTOC(bool skip_selector = false);
+    bool CreateHTMLTOC();
     void EditTOCDialog();
-    void CreateHTMLTOC();
 
     void ChangeCasing(QAction* act);
 
@@ -1037,6 +1068,10 @@ private:
 
     bool m_FRVisible;
 
+    bool m_UsingAutomate;
+    QStringList m_AutomateLog;
+    QString m_AutomatePluginParameter;
+    
     /**
      * Holds all the widgets Qt Designer created for us.
      */
