@@ -1,7 +1,7 @@
 /************************************************************************
 **
 **  Copyright (C) 2015-2021  Kevin B. Hendricks, Stratford Ontario Canada
-**  Copyright (C) 2019-2020  Doug Massay
+**  Copyright (C) 2019-2021  Doug Massay
 **  Copyright (C) 2012       Dave Heiland, John Schember
 **
 **  This file is part of Sigil.
@@ -28,7 +28,6 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QToolBar>
-#include <QtWebEngineWidgets/QWebEngineView>
 #include <QDir>
 #include <QRegularExpression>
 #include <QRegularExpressionMatch>
@@ -36,6 +35,7 @@
 #include <QStyleOptionFrame>
 #include <QTimer>
 #include <QProgressBar>
+#include <QApplication>
 #include <QDebug>
 
 #include "MainUI/PreviewWindow.h"
@@ -52,6 +52,18 @@ static const QStringList HEADERTAGS = QStringList() << "h1" << "h2" << "h3" << "
 
 static const QString SETTINGS_GROUP = "previewwindow";
 
+static const QString MATHJAX_CLEANUP = 
+   "<script type=\"text/x-mathjax-config\">"
+   "  MathJax.Hub.Register.StartupHook('End', function () {"
+   "    var mscripts = document.querySelectorAll(\"script[type='math/mml']\");"
+   "    function pruneScripts(item, index) {"
+   "      item.parentNode.removeChild(item);"
+   "    }"
+   "    mscripts.forEach(pruneScripts);"
+   "  });"
+   "</script>";;
+
+
 #define DBG if(0)
 
 PreviewWindow::PreviewWindow(QWidget *parent)
@@ -66,7 +78,8 @@ PreviewWindow::PreviewWindow(QWidget *parent)
     m_progress(new QProgressBar(this)),
     m_Filepath(QString()),
     m_titleText(QString()),
-    m_updatingPage(false)
+    m_updatingPage(false),
+    m_usingMathML(false)
 {
     m_progress->reset();
     m_progress->setMinimum(0);
@@ -162,11 +175,23 @@ void PreviewWindow::paintEvent(QPaintEvent *event)
     if (isFloating()) {
         QStyleOptionFrame options;
         options.initFrom(this);
+
+#ifdef Q_OS_MAC
+        // This is needed for Qt6 but works on Qt5 as well
+        options.palette = QApplication::palette();
+#endif
+
         painter.drawPrimitive(QStyle::PE_FrameDockWidget, options);
     }
     QStyleOptionDockWidget options;
     initStyleOption(&options);
     options.title = titleText();
+
+#ifdef Q_OS_MAC
+    // This is needed for Qt6 but works on Qt5 as well
+    options.palette = QApplication::palette();
+#endif
+
     painter.drawControl(QStyle::CE_DockWidgetTitle, options);
 }
 
@@ -234,6 +259,10 @@ void PreviewWindow::SetupView()
     QApplication::restoreOverrideCursor();
 }
 
+// Note every call to Update Page needs to be followed by a call
+// to Zoom() as it is not properly zooming after loading
+// But Zoom() is not done synchronously so after zooming
+// you must delay before trying to update Preview to a specific location
 bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<ElementIndex> location)
 {
 
@@ -249,15 +278,19 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
         return false;
     }
 
+    m_updatingPage = true;
+    SetCaretLocation(location);
     m_progress->setRange(0,100);
     m_progress->setValue(0);
     m_OverlayTimer.start();
-    
-    m_updatingPage = true;
-    m_location = location;
+
+    QRegularExpression mathused("<\\s*math [^>]*>");
+    QRegularExpressionMatch mo = mathused.match(text);
+    m_usingMathML = mo.hasMatch();
 
     DBG qDebug() << "PV UpdatePage " << filename_url;
-    DBG foreach(ElementIndex ei, location) qDebug()<< "PV name: " << ei.name << " index: " << ei.index;
+    DBG { foreach(ElementIndex ei, location) qDebug()<< "PV name: " << ei.name << " index: " << ei.index; }
+
 
     //if isDarkMode is set, inject a local style in head
     SettingsStore settings;
@@ -282,12 +315,10 @@ bool PreviewWindow::UpdatePage(QString filename_url, QString text, QList<Element
 
     // If this page uses mathml tags, inject a polyfill
     // MathJax.js so that the mathml appears in the Preview Window
-    QRegularExpression mathused("<\\s*math [^>]*>");
-    QRegularExpressionMatch mo = mathused.match(text);
-    if (mo.hasMatch()) {
+    if (m_usingMathML) {
         int endheadpos = text.indexOf("</head>");
         if (endheadpos > 1) {
-            QString inject_mathjax = 
+            QString inject_mathjax = MATHJAX_CLEANUP + 
               "<script type=\"text/javascript\" async=\"async\" "
               "src=\"" + m_mathjaxurl + "\"></script>\n";
             text.insert(endheadpos, inject_mathjax);
@@ -332,15 +363,22 @@ void PreviewWindow::UpdatePageDone()
     DBG qDebug() << "PreviewWindow UpdatePage load is Finished";
     DBG qDebug() << "PreviewWindow UpdatePage final step scroll to location";
 
-    m_Preview->StoreCaretLocationUpdate(m_location);
-    m_Preview->ExecuteCaretUpdate();
+    // Zoom is handled internally to mPreview just before this is called
     UpdateWindowTitle();
-    m_updatingPage = false;
-    m_Preview->Zoom();
     m_OverlayTimer.stop();
     m_progress->setValue(100);
     m_progress->reset();
     m_Preview->HideOverlay();
+    // need to delay long enough for Zoom changes to be reflected in View widget
+    // before trying to center it on a location.
+    QTimer::singleShot(30, this, SLOT(DelayedScrollTo()));
+    m_updatingPage = false;
+}
+
+void PreviewWindow::DelayedScrollTo()
+{
+    m_Preview->StoreCaretLocationUpdate(m_location);
+    m_Preview->ExecuteCaretUpdate();
 }
 
 void PreviewWindow::ScrollTo(QList<ElementIndex> location)
@@ -349,8 +387,12 @@ void PreviewWindow::ScrollTo(QList<ElementIndex> location)
     if (!m_Preview->isVisible()) {
         return;
     }
-    m_Preview->StoreCaretLocationUpdate(location);
-    m_Preview->ExecuteCaretUpdate();
+    DBG { foreach(ElementIndex ei, location) qDebug() << "name: " << ei.name << " index: " << ei.index; }
+    SetCaretLocation(location);
+    if (!m_updatingPage) {
+        m_Preview->StoreCaretLocationUpdate(m_location);
+        m_Preview->ExecuteCaretUpdate();
+    }
 }
 
 void PreviewWindow::UpdateWindowTitle()
@@ -404,10 +446,34 @@ QList<ElementIndex> PreviewWindow::GetCaretLocation()
 {
     DBG qDebug() << "PreviewWindow in GetCaretLocation";
     QList<ElementIndex> hierarchy = m_Preview->GetCaretLocation();
-    DBG foreach(ElementIndex ei, hierarchy) qDebug() << "name: " << ei.name << " index: " << ei.index;
+    for (int i = 0; i < hierarchy.length(); i++) {
+        if (m_usingMathML && (hierarchy[i].name == "body")) {
+            // compensate for MathJax added two divs injected as first children of body
+            hierarchy[i].index = hierarchy[i].index - 2;
+        }
+        DBG qDebug() << "name: " << hierarchy[i].name << " index: " << hierarchy[i].index;
+    }
     return hierarchy;
 }
 
+
+void PreviewWindow::SetCaretLocation(const QList<ElementIndex> &loc)
+{
+    DBG qDebug() << "PreviewWindow in SetCaretLocation";
+    QList<ElementIndex> hierarchy;
+    foreach(ElementIndex ei, loc) {
+        if (m_usingMathML && (ei.name == "body")) {
+            // compensate for MathJax added two divs injected as first children of body
+            ei.index = ei.index + 2;
+        }
+        hierarchy << ei;
+        DBG qDebug() << "name: " << ei.name << " index: " << ei.index;
+    }
+    m_location = hierarchy;
+    // Any Zoom must come *before* we do any caret updating
+    // *BUT* Zoom() does not complete instantaneously/synchronously
+}
+
 void PreviewWindow::SetZoomFactor(float factor)
 {
     m_Preview->SetZoomFactor(factor);
