@@ -25,7 +25,7 @@
 #include <QtCore/QFile>
 #include <QtCore/QSignalMapper>
 #include <QtWidgets/QAbstractItemView>
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QCompleter>
 #include <QtGui/QContextMenuEvent>
 #include <QtWidgets/QMenu>
@@ -41,7 +41,11 @@ FindReplaceQLineEdit::FindReplaceQLineEdit(QWidget *parent)
       m_searchMapper(new QSignalMapper(this)),
       m_tokeniseEnabled(true)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(m_searchMapper, SIGNAL(mapped(const QString &)), m_FindReplace, SLOT(LoadSearchByName(const QString &)));
+#else
+    connect(m_searchMapper, SIGNAL(mappedString(const QString &)), m_FindReplace, SLOT(LoadSearchByName(const QString &)));
+#endif
 }
 
 FindReplaceQLineEdit::~FindReplaceQLineEdit()
@@ -57,6 +61,18 @@ void FindReplaceQLineEdit::contextMenuEvent(QContextMenuEvent *event)
         topAction = menu->actions().at(0);
     }
 
+    QAction *clearHistoryAction = new QAction(tr("Clear Find Replace History"), menu);
+    connect(clearHistoryAction, SIGNAL(triggered()), m_FindReplace, SLOT(ClearHistory()));
+
+    if (topAction) {
+        menu->insertAction(topAction, clearHistoryAction);
+        menu->insertSeparator(topAction);
+    } else {
+        menu->addAction(clearHistoryAction);
+    }
+
+    topAction = clearHistoryAction;
+
     if (m_tokeniseEnabled) {
         QAction *tokeniseAction = new QAction(tr("Tokenise Selection"), menu);
         connect(tokeniseAction, SIGNAL(triggered()), m_FindReplace, SLOT(TokeniseSelection()));
