@@ -152,39 +152,39 @@ void GuideItems::SetGuideItemsMap()
     QStringList data;
     data <<
         tr("Acknowledgements") << "acknowledgements" << tr("A passage containing acknowledgments to entities involved in the realization of the work.") <<
-        tr("Afterword [other.]") << "other.afterword" << tr("A closing statement from the author or a person of importance to the story, typically providing insight into how the story came to be written, its significance or related events that have transpired since its timeline.") <<
-        tr("Appendix [other.]") << "other.appendix" << tr("Supplemental information.") <<
-        tr("Back Matter [other.]") << "other.backmatter" << tr("Ancillary material occurring after the main content of a publication, such as indices, appendices, etc.") <<
+        tr("Afterword") << "other.afterword" << tr("A closing statement from the author or a person of importance to the story, typically providing insight into how the story came to be written, its significance or related events that have transpired since its timeline.") <<
+        tr("Appendix") << "other.appendix" << tr("Supplemental information.") <<
+        tr("Back Matter") << "other.backmatter" << tr("Ancillary material occurring after the main content of a publication, such as indices, appendices, etc.") <<
         tr("Bibliography") << "bibliography" << tr("A list of works cited.") <<
         tr("Text") << "text" << tr("The start of the main text content of a publication.") <<
         tr("Colophon") << "colophon" << tr("A brief description usually located at the end of a publication, describing production notes relevant to the edition.") <<
-        tr("Conclusion [other.]") << "other.conclusion" << tr("An ending section that typically wraps up the work.") <<
-        tr("Contributors [other.]") << "other.contributors" << tr("A list of contributors to the work.") <<
+        tr("Conclusion") << "other.conclusion" << tr("An ending section that typically wraps up the work.") <<
+        tr("Contributors") << "other.contributors" << tr("A list of contributors to the work.") <<
         tr("Copyright Page") << "copyright-page" << tr("The copyright page of the work.") <<
         tr("Cover") << "cover" << tr("The publications cover(s), jacket information, etc.") <<
         tr("Dedication") << "dedication" << tr("An inscription addressed to one or several particular person(s).") <<
-        tr("Epilogue [other.]") << "other.epilogue" << tr("A concluding section that is typically written from a later point in time than the main story, although still part of the narrative.") <<
+        tr("Epilogue") << "other.epilogue" << tr("A concluding section that is typically written from a later point in time than the main story, although still part of the narrative.") <<
         tr("Epigraph") << "epigraph" << tr("A quotation that is pertinent but not integral to the text.") <<
-        tr("Errata [other.]") << "other.errata" << tr("Publication errata, in printed works typically a loose sheet inserted by hand; sometimes a bound page that contains corrections for mistakes in the work.") <<
-        tr("Footnotes [other.]") << "other.footnotes" << tr("A collection of notes appearing at the bottom of a page.") <<
+        tr("Errata") << "other.errata" << tr("Publication errata, in printed works typically a loose sheet inserted by hand; sometimes a bound page that contains corrections for mistakes in the work.") <<
+        tr("Footnotes") << "other.footnotes" << tr("A collection of notes appearing at the bottom of a page.") <<
         tr("Foreword") << "foreword" << tr("An introductory section that precedes the work, typically not written by the work's author.") <<
-        tr("Front Matter [other.]") << "other.frontmatter" << tr("Preliminary material to the main content of a publication, such as tables of contents, dedications, etc.") <<
+        tr("Front Matter") << "other.frontmatter" << tr("Preliminary material to the main content of a publication, such as tables of contents, dedications, etc.") <<
         tr("Glossary") << "glossary" << tr("An alphabetical list of terms in a particular domain of knowledge, with the definitions for those terms.") <<
-        tr("Half Title Page [other.]") << "other.halftitlepage" << tr("The half title page of the work which carries just the title itself.") <<
-        tr("Imprimatur [other.]") << "other.imprimatur" << tr("A formal statement authorizing the publication of the work.") <<
-        tr("Imprint [other.]") << "other.imprint" << tr("Information relating to the publication or distribution of the work.") <<
+        tr("Half Title Page") << "other.halftitlepage" << tr("The half title page of the work which carries just the title itself.") <<
+        tr("Imprimatur") << "other.imprimatur" << tr("A formal statement authorizing the publication of the work.") <<
+        tr("Imprint") << "other.imprint" << tr("Information relating to the publication or distribution of the work.") <<
         tr("Index") << "index" << tr("A detailed list, usually arranged alphabetically, of the specific information in a publication.") <<
-        tr("Introduction [other.]") << "other.introduction" << tr("A section in the beginning of the work, typically introducing the reader to the scope or nature of the work's content.") <<
+        tr("Introduction") << "other.introduction" << tr("A section in the beginning of the work, typically introducing the reader to the scope or nature of the work's content.") <<
         tr("List of Illustrations") << "loi" << tr("A listing of illustrations included in the work.") <<
-        tr("List of Audio Clips [other.]") << "other.loa" << tr("A listing of audio clips included in the work.") <<
+        tr("List of Audio Clips") << "other.loa" << tr("A listing of audio clips included in the work.") <<
         tr("List of Tables") << "lot" << tr("A listing of tables included in the work.") <<
-        tr("List of Video Clips [other.]") << "other.lov" << tr("A listing of video clips included in the work.") <<
+        tr("List of Video Clips") << "other.lov" << tr("A listing of video clips included in the work.") <<
         tr("Notes") << "notes" << tr("A collection of notes. It can be used to identify footnotes, rear notes, marginal notes, inline notes, and similar when legacy naming conventions are not desired. Status: Deprecated - Replaced by: 'footnotes', 'rearnotes'") <<
-        tr("Other Credits [other.]") << "other.other-credits" << tr("Acknowledgments of previously published parts of the work, illustration credits, and permission to quote from copyrighted material.") <<
-        tr("Preamble [other.]") << "other.preamble" << tr("A section in the beginning of the work, typically containing introductory and/or explanatory prose regarding the scope or nature of the work's content") <<
+        tr("Other Credits") << "other.other-credits" << tr("Acknowledgments of previously published parts of the work, illustration credits, and permission to quote from copyrighted material.") <<
+        tr("Preamble") << "other.preamble" << tr("A section in the beginning of the work, typically containing introductory and/or explanatory prose regarding the scope or nature of the work's content") <<
         tr("Preface") << "preface" << tr("An introductory section that precedes the work, typically written by the work's author.") <<
-        tr("Prologue [other.]") << "other.prologue" << tr("An introductory section that sets the background to a story, typically part of the narrative.") <<
-        tr("Rear Notes [other.]") << "other.rearnotes" << tr("A collection of notes appearing at the rear (backmatter) of the work, or at the end of a section.") <<
+        tr("Prologue") << "other.prologue" << tr("An introductory section that sets the background to a story, typically part of the narrative.") <<
+        tr("Rear Notes") << "other.rearnotes" << tr("A collection of notes appearing at the rear (backmatter) of the work, or at the end of a section.") <<
         tr("Title Page") << "title-page" << tr("A page at the beginning of a book giving its title, authors, publisher and other publication information.") <<
         tr("Table of Contents") << "toc" << tr("A table of contents which is a list of the headings or parts of the book or document, organized in the order in which they appear. Typically appearing in the work's frontmatter, or at the beginning of a section.");
 
