@@ -1,8 +1,8 @@
 /************************************************************************
 **
-**  Copyright (C) 2019  Kevin B. Hendricks, Stratford, Ontario, Canada
-**  Copyright (C) 2019  Doug Massay
-**  Copyright (C) 2012  Daniel Pavel <daniel.pavel@gmail.com>
+**  Copyright (C) 2019-2021 Kevin B. Hendricks, Stratford, Ontario, Canada
+**  Copyright (C) 2019      Doug Massay
+**  Copyright (C) 2012      Daniel Pavel <daniel.pavel@gmail.com>
 **
 **  This file is part of Sigil.
 **
@@ -162,6 +162,77 @@ bool OpenExternally::openFile(const QString &filePath, const QString &applicatio
     return false;
 }
 
+
+bool OpenExternally::openFileWithXEditor(const QString& filePath, const QString &application, int spinenum)
+{
+    QString spineno = QString::number(spinenum);
+
+#if defined(Q_OS_MAC)
+
+    if (QFile::exists(filePath) && QDir(application).exists()) {
+        QStringList arguments = QStringList() << "-a" << application << "--args" << filePath << spineno;
+        return QProcess::startDetached("/usr/bin/open", arguments);
+    }
+
+#elif defined(Q_OS_WIN32)
+
+    if (QFile::exists(filePath) && QFile::exists(application)) {
+        QProcess proc;
+        bool batch;
+        // Handle bat|cmd files differently than exes
+        if (QFileInfo(application).suffix() == "bat" || QFileInfo(application).suffix() == "cmd") {
+            DBG qDebug() << "External bat|cmd file being launched: " << application;
+            batch = true;
+            proc.setProgram("C:\\Windows\\System32\\cmd.exe");
+            proc.setArguments(QStringList("/c"));
+            // Filename only. No other way to get the cmd string properly quoted/escaped otherwise. We'll change
+            // the working directory to the directory where the scripts resides so that it can be found/launched.
+            QString nativeArguments;
+            nativeArguments = QString(QFileInfo(application).fileName() + " \"" + QDir::toNativeSeparators(filePath) + "\"" + " %1").arg(spineno);
+            proc.setNativeArguments(nativeArguments);
+        } else {
+            DBG qDebug() << "External binary program being launched: " << application;
+            batch = false;
+            proc.setProgram(application);
+            QStringList arguments;
+            arguments << QDir::toNativeSeparators(filePath) << spineno;
+            proc.setArguments(arguments);
+        }
+        // Change to the directory of the application/script first. This is
+        // very important for batch files, but doesn't matter much for exes.
+        proc.setWorkingDirectory(QDir::toNativeSeparators(QFileInfo(application).canonicalPath()));
+        if (batch) {
+            // This nonsense (which requires including Windows.h) is necessary to launch a new
+            // console window (which must subsequently be hidden) because Qt gui apps don't have
+            // a console for the new process to inherit (which is default for QProcess::startDetached).
+            // See: https://doc-snapshots.qt.io/qt5-5.13/qprocess.html#CreateProcessArgumentModifier-typedef
+            proc.setCreateProcessArgumentsModifier([] (QProcess::CreateProcessArguments *args)
+            {
+                args->flags |= CREATE_NEW_CONSOLE;
+                args->startupInfo->dwFlags = STARTF_USESHOWWINDOW;
+                args->startupInfo->wShowWindow = SW_HIDE;
+            });
+        }
+        DBG qDebug() << "QProcess program: " << proc.program();
+        DBG qDebug() << "QProcess arguments: " << proc.arguments();
+        if (batch) {
+            DBG qDebug() << "QProcess Native arguments: " << proc.nativeArguments();
+        }
+        return proc.startDetached();
+    }
+
+#else
+
+    if (QFile::exists(filePath) && QFile::exists(application)) {
+        QStringList arguments = QStringList(QDir::toNativeSeparators(filePath));
+        arguments << spineno;
+        return QProcess::startDetached(QDir::toNativeSeparators(application), arguments, QFileInfo(filePath).absolutePath());
+    }
+
+#endif
+    return false;
+}
+
 const QStringList OpenExternally::editorsForResourceType(const Resource::ResourceType type)
 {
     QStringList editorPaths = QStringList();
@@ -170,13 +241,13 @@ const QStringList OpenExternally::editorsForResourceType(const Resource::Resourc
         settings.beginGroup(SETTINGS_GROUP);
         const QString editorsKey = QString("editors_") + RESOURCE_TYPE_NAME(type);
         if (settings.contains(editorsKey)) {
-	    QStringList editors = settings.value(editorsKey).toStringList();
-	    foreach(QString editor, editors) {
-  	        const QStringList edata = editor.split(SEP);
-		const QString editor_name = edata[nameField];
-		const QString editor_path = edata[pathField];
-	        if (QFile::exists(editor_path)) editorPaths.append(editor_path);
-	    }
+            QStringList editors = settings.value(editorsKey).toStringList();
+            foreach(QString editor, editors) {
+                const QStringList edata = editor.split(SEP);
+                const QString editor_name = edata[nameField];
+                const QString editor_path = edata[pathField];
+                if (QFile::exists(editor_path)) editorPaths.append(editor_path);
+            }   
         }
     }
     return editorPaths;
@@ -190,16 +261,16 @@ const QStringList OpenExternally::editorDescriptionsForResourceType(const Resour
         settings.beginGroup(SETTINGS_GROUP);
         const QString editorsKey = QString("editors_") + RESOURCE_TYPE_NAME(type);
         if (settings.contains(editorsKey)) {
-	    QStringList editors = settings.value(editorsKey).toStringList();
-	    foreach(QString editor, editors) {
-  	        const QStringList edata = editor.split(SEP);
-		QString editor_name = edata[nameField];
-		const QString editor_path = edata[pathField];
-	        if (QFile::exists(editor_path)) {
-  		    if (editor_name.isEmpty()) editor_name = prettyApplicationName(editor_path);
-		    editorDescriptions.append(editor_name);
-		}
-	    }
+            QStringList editors = settings.value(editorsKey).toStringList();
+            foreach(QString editor, editors) {
+                const QStringList edata = editor.split(SEP);
+                QString editor_name = edata[nameField];
+                const QString editor_path = edata[pathField];
+                if (QFile::exists(editor_path)) {
+                    if (editor_name.isEmpty()) editor_name = prettyApplicationName(editor_path);
+                    editorDescriptions.append(editor_name);
+                }
+            }
         }
     }
     return editorDescriptions;
@@ -230,8 +301,8 @@ const QString OpenExternally::selectEditorForResourceType(const Resource::Resour
     QString last_name;
     if (!editors.isEmpty()) {
         QStringList edata = editors[0].split(SEP);
-	last_name = edata[nameField];
-	last_editor = edata[pathField];
+        last_name = edata[nameField];
+        last_editor = edata[pathField];
     }
     if (last_editor.isEmpty() || !QFile::exists(last_editor)) {
         last_editor = LAST_LOCATION;
@@ -263,7 +334,7 @@ const QString OpenExternally::selectEditorForResourceType(const Resource::Resour
                                  last_editor,
                                  NAME_FILTER,
                                  0,
-				 options);
+                                 options);
 
     if (!selectedFile.isEmpty()) {
         // Let the user choose a friendly menu name for the application
@@ -277,12 +348,12 @@ const QString OpenExternally::selectEditorForResourceType(const Resource::Resour
             editorDescription = prettyName;
         }
         const QString editor_data = editorDescription + SEP + selectedFile;
-	editors.removeOne(editor_data);
-	editors.prepend(editor_data);
-	// limit of 5 editors per resource type
-	while(editors.size() > 5) {
-	    editors.removeLast();
-	}
+        editors.removeOne(editor_data);
+        editors.prepend(editor_data);
+        // limit of 5 editors per resource type
+        while(editors.size() > 5) {
+            editors.removeLast();
+        }
         settings.setValue(editorsKey, editors);
         LAST_LOCATION = selectedFile;
     }
