@@ -1,6 +1,6 @@
 /************************************************************************
 **
-**  Copyright (C) 2018, 2019 Kevin B. Hendricks, Stratford, Ontario
+**  Copyright (C) 2018-2021 Kevin B. Hendricks, Stratford, Ontario
 **  Copyright (C) 2012 John Schember <john@nachtimwald.com>
 **  Copyright (C) 2012 Dave Heiland
 **  Copyright (C) 2012 Grant Drake
@@ -24,6 +24,7 @@
 
 #include <QtCore/QCoreApplication>
 #include <QByteArray>
+#include <QFile>
 #include <QDataStream>
 #include <QtCore/QTime>
 #include <QRegularExpression>
@@ -32,6 +33,14 @@
 #include "Misc/Utility.h"
 #include "sigil_constants.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
+#endif
+
 static const QString SETTINGS_FILE          = "sigil_clips.ini";
 static const QString SETTINGS_GROUP         = "clip_entries";
 static const QString ENTRY_NAME             = "Name";
@@ -269,44 +278,6 @@ ClipEditorModel::clipEntry *ClipEditorModel::GetEntryFromNumber(int clip_number)
     return GetEntry(GetItemFromNumber(clip_number));
 }
 
-#if 0
-// this original code had too many exit paths with the potential for off
-// by one for valid item in final row since row is incremented early
-
-QStandardItem *ClipEditorModel::GetItemFromNumber(int clip_number)
-{
-    QStandardItem *item = NULL;
-    
-    clip_number--;
-
-    if (clip_number < 0) {
-        return item;
-    }
-
-    // Get the entry for the number, skipping over group entries so that
-    // the entries can be at top or bottom, or anywhere, in the list.
-    int row = 0;
-    int rows = invisibleRootItem()->rowCount();
-    for (int i = 0; i <= clip_number; i++) {
-        while (row < rows) {
-            item = invisibleRootItem()->child(row, 0);
-            row++;
-            if (!item || !item->data(IS_GROUP_ROLE).toBool()) {
-                break;
-            }
-        }
-        if (row >= rows) {
-            break;
-        }
-        if (i == clip_number) {
-            return item;
-        }
-    }
-
-    return NULL;
-}
-#endif
-
 
 // Let's try this approach to try to address those concerns
 QStandardItem *ClipEditorModel::GetItemFromNumber(int clip_number)
@@ -318,9 +289,9 @@ QStandardItem *ClipEditorModel::GetItemFromNumber(int clip_number)
     int rows = invisibleRootItem()->rowCount();
     for (int r = 0; r < rows; r++) {
         item = invisibleRootItem()->child(r, 0);
-	if (!item || !item->data(IS_GROUP_ROLE).toBool()) cnt++;
-	if (cnt > clip_number) return NULL;
-	if (cnt == clip_number) return item;
+        if (!item || !item->data(IS_GROUP_ROLE).toBool()) cnt++;
+        if (cnt > clip_number) return NULL;
+        if (cnt == clip_number) return item;
     }
     return NULL;
 }
@@ -388,7 +359,7 @@ void ClipEditorModel::LoadData(const QString &filename, QStandardItem *item)
         entry->fullname = fullname;
         entry->text = ss.value(ENTRY_TEXT).toString();
         AddFullNameEntry(entry, item);
-	delete entry;
+        delete entry;
     }
     ss.endArray();
 }
@@ -411,7 +382,7 @@ void ClipEditorModel::AddFullNameEntry(ClipEditorModel::clipEntry *entry, QStand
     QString entry_name = entry->name;
 
     if (entry->name.contains("/")) {
-        QStringList group_names = entry->name.split("/", QString::SkipEmptyParts);
+        QStringList group_names = entry->name.split("/", QT_ENUM_SKIPEMPTYPARTS);
         entry_name = group_names.last();
 
         if (!entry->is_group) {
@@ -434,8 +405,8 @@ void ClipEditorModel::AddFullNameEntry(ClipEditorModel::clipEntry *entry, QStand
                 new_entry->is_group = true;
                 new_entry->name = group_name;
                 parent_item = AddEntryToModel(new_entry, new_entry->is_group, parent_item, parent_item->rowCount());
-		// fix memory leak
-		delete new_entry;
+                // fix memory leak
+                delete new_entry;
             }
         }
         row = parent_item->rowCount();
@@ -683,9 +654,9 @@ QString ClipEditorModel::SaveData(QList<ClipEditorModel::clipEntry *> entries, c
         QList<QStandardItem *> items = GetNonParentItems(invisibleRootItem());
 
         if (!items.isEmpty()) {
-  	    // GetEntries calls GetEntry which creates each entry with new
+            // GetEntries calls GetEntry which creates each entry with new
             entries = GetEntries(items);
-	    clean_up_needed = true;
+            clean_up_needed = true;
         }
     }
 
@@ -705,9 +676,9 @@ QString ClipEditorModel::SaveData(QList<ClipEditorModel::clipEntry *> entries, c
 
             // delete each entry if we created them above 
             if (clean_up_needed) {
-	        foreach(ClipEditorModel::clipEntry* entry, entries) {
-	            delete entry;
-	        }
+                foreach(ClipEditorModel::clipEntry* entry, entries) {
+                    delete entry;
+                }
             }
             return message;
         }
@@ -727,7 +698,7 @@ QString ClipEditorModel::SaveData(QList<ClipEditorModel::clipEntry *> entries, c
         // delete each entry if we created them above
         if (clean_up_needed) {
             foreach(ClipEditorModel::clipEntry* entry, entries) {
-	        delete entry;
+                delete entry;
             }
         }
         ss.endArray();
