@@ -36,6 +36,14 @@
 #include "sigil_constants.h"
 #include "sigil_exception.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
+#endif
+
 static const QString SETTINGS_FILE          = "sigil_searches_v2.ini";
 static const QString OLD_SETTINGS_FILE      = "sigil_searches.ini";
 
@@ -414,7 +422,7 @@ void SearchEditorModel::AddFullNameEntry(SearchEditorModel::searchEntry *entry,
     QString entry_name = entry->name;
 
     if (entry->name.contains("/")) {
-        QStringList group_names = entry->name.split("/", QString::SkipEmptyParts);
+        QStringList group_names = entry->name.split("/", QT_ENUM_SKIPEMPTYPARTS);
         entry_name = group_names.last();
 
         if (!entry->is_group) {
@@ -538,6 +546,7 @@ QString SearchEditorModel::BuildControlsToolTip(const QString & controls)
 
 QStandardItem *SearchEditorModel::AddEntryToModel(SearchEditorModel::searchEntry *entry, bool is_group, QStandardItem *parent_item, int row)
 {
+    bool clean_up_needed = false;
     // parent_item must be a group item
     if (!parent_item) {
         parent_item = invisibleRootItem();
@@ -546,6 +555,7 @@ QStandardItem *SearchEditorModel::AddEntryToModel(SearchEditorModel::searchEntry
     // Create an empty entry if none supplied
     if (!entry) {
         entry = new SearchEditorModel::searchEntry();
+        clean_up_needed = true;
         entry->is_group = is_group;
 
         if (!is_group) {
@@ -607,6 +617,7 @@ QStandardItem *SearchEditorModel::AddEntryToModel(SearchEditorModel::searchEntry
         new_item = parent_item->child(row, 0);
     }
 
+    if (clean_up_needed) delete entry;
     SetDataModified(true);
     return new_item;
 }
