@@ -35,6 +35,13 @@
 #include "string_buffer.h"
 #include "error.h"
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
+#endif
 
 static std::unordered_set<std::string> nonbreaking_inline  = { 
     "a","abbr","acronym","b","bdo","big","br","button","cite","code","del",
@@ -373,6 +380,23 @@ QString GumboInterface::perform_link_updates(const QString& newcsslinks)
 }
 
 
+QString GumboInterface::perform_javascript_updates(const QString& newjslinks)
+{
+    m_newjslinks = newjslinks.toStdString();
+    QString result = "";
+    if (!m_source.isEmpty()) {
+        if (m_output == NULL) {
+            parse();
+        }
+        enum UpdateTypes doupdates = JavascriptUpdates;
+        std::string utf8out = serialize(m_output->document, doupdates);
+        rtrim(utf8out);
+        result =  "<?xml version=\"1.0\" encoding=\"utf-8\"?>\n" + QString::fromStdString(utf8out);
+    }
+    return result;
+}
+
+
 GumboNode * GumboInterface::get_document_node()
 {
     if (!m_source.isEmpty()) {
@@ -501,7 +525,7 @@ QString GumboInterface::get_qwebpath_to_node(GumboNode* node)
 
 GumboNode* GumboInterface::get_node_from_qwebpath(QString webpath) 
 {
-    QStringList path_pieces = webpath.split(",", QString::SkipEmptyParts);
+    QStringList path_pieces = webpath.split(",", QT_ENUM_SKIPEMPTYPARTS);
     GumboNode* node = get_root_node();
     GumboNode* end_node = node;
     for (int i=0; i < path_pieces.count() - 1 ; ++i) {
@@ -1298,14 +1322,47 @@ std::string GumboInterface::serialize(GumboNode* node, enum UpdateTypes doupdate
     bool is_href_src_tag           = in_set(href_src_tags, tagname);
     bool in_xml_ns                 = node->v.element.tag_namespace != GUMBO_NAMESPACE_HTML;
     // bool is_inline                 = in_set(nonbreaking_inline, tagname);
+    bool is_jslink = false;
 
+
+    // handle special case of stylesheet link missing type attribute
+    if ((tagname == "link") && (node->parent->type == GUMBO_NODE_ELEMENT) && 
+        (node->parent->v.element.tag == GUMBO_TAG_HEAD)) {
+        const GumboVector * attribs = &node->v.element.attributes;
+        GumboAttribute* relatt = gumbo_get_attribute(attribs, "rel");
+        GumboAttribute* typeatt = gumbo_get_attribute(attribs, "type");
+        if (relatt && !typeatt) {
+            std::string rel = relatt->value;
+            if (rel == "stylesheet") {
+                gumbo_element_set_attribute(&node->v.element, "type", "text/css");
+            }
+        }
+    }
+    
     // build attr string  
-    const GumboVector * attribs = &node->v.element.attributes;
+    GumboVector * attribs = &node->v.element.attributes;
     for (unsigned int i=0; i< attribs->length; ++i) {
         GumboAttribute* at = static_cast<GumboAttribute*>(attribs->data[i]);
         atts.append(build_attributes(at, no_entity_substitution, ((doupdates & SourceUpdates) && is_href_src_tag), (doupdates & StyleUpdates)));
     }
 
+    if (tagname == "script") {
+        if ((node->parent->type == GUMBO_NODE_ELEMENT) && 
+            (node->parent->v.element.tag == GUMBO_TAG_HEAD)) {
+            GumboAttribute* srcatt = gumbo_get_attribute(attribs, "src");
+            GumboAttribute* typeatt = gumbo_get_attribute(attribs, "type");
+            if (srcatt && typeatt) {
+                std::string script_src = srcatt->value;
+                std::string script_type = typeatt->value;
+                if (script_src.find(":") == std::string::npos) {
+                    if ((script_type == "application/javascript") || (script_type == "text/javascript")) {
+                        is_jslink = true;
+                    }
+                }
+            }
+        }
+    }
+    
     // Make sure that the xmlns attribute exists as an html tag attribute
     if (tagname == "html") {
         if (atts.find("xmlns=") == std::string::npos) {
@@ -1355,10 +1412,15 @@ std::string GumboInterface::serialize(GumboNode* node, enum UpdateTypes doupdate
     if ((doupdates & LinkUpdates) && (tagname == "link") && 
         (node->parent->type == GUMBO_NODE_ELEMENT) && 
         (node->parent->v.element.tag == GUMBO_TAG_HEAD)) {
-      return "";
+        return "";
+    }
+
+    if ((doupdates & JavascriptUpdates) && is_jslink) {
+        return "";
     }
 
     results.append("<"+tagname+atts+close+">");
+    
     if (need_special_handling) results.append("\n");
     results.append(contents);
 
@@ -1366,6 +1428,10 @@ std::string GumboInterface::serialize(GumboNode* node, enum UpdateTypes doupdate
         results.append(m_newcsslinks);
     }
 
+    if ((doupdates & JavascriptUpdates) && (tagname == "head")) {
+        results.append(m_newjslinks);
+    }
+
     results.append(closeTag);
     if (need_special_handling) results.append("\n");
     return results;
@@ -1504,6 +1570,20 @@ std::string GumboInterface::prettyprint(GumboNode* node, int lvl, const std::str
     bool is_inline = in_set(nonbreaking_inline, tagname);
     bool in_xml_ns = node->v.element.tag_namespace != GUMBO_NAMESPACE_HTML;
 
+    // handle special case of stylesheet link missing type attribute
+    if ((tagname == "link") && (node->parent->type == GUMBO_NODE_ELEMENT) &&
+        (node->parent->v.element.tag == GUMBO_TAG_HEAD)) {
+        const GumboVector * attribs = &node->v.element.attributes;
+        GumboAttribute* relatt = gumbo_get_attribute(attribs, "rel");
+        GumboAttribute* typeatt = gumbo_get_attribute(attribs, "type");
+        if (relatt && !typeatt) {
+            std::string rel = relatt->value;
+            if (rel == "stylesheet") {
+                gumbo_element_set_attribute(&node->v.element, "type", "text/css");
+            }
+        }
+    }
+    
     // build attr string
     std::string atts = "";
     bool no_entity_substitution = in_set(no_entity_sub, tagname);
