@@ -6,14 +6,21 @@ from __future__ import (unicode_literals, division, absolute_import,
 
 import sys
 
+using_new_findpython3 = bool(${USE_NEWER_FINDPYTHON3})
 py_ver = ''.join(map(str, sys.version_info[:2]))
-py_exe = '${PYTHON_EXECUTABLE}'
-py_lib_temp = '${PYTHON_LIBRARIES}'
+if using_new_findpython3:
+    py_exe = '${Python3_EXECUTABLE}'
+    py_lib_temp = '${Python3_LIBRARIES}'
+    py_inc = '${Python3_INCLUDE_DIRS}'
+else:
+    py_exe = '${PYTHON_EXECUTABLE}'
+    py_lib_temp = '${PYTHON_LIBRARIES}'
+    py_inc = '${PYTHON_INCLUDE_DIRS}'
+
 if not sys.platform.startswith('win') and not sys.platform.startswith('darwin'):    
     if not py_lib_temp.endswith('.1.0'):
         py_lib_temp = py_lib_temp + '.1.0'
 py_lib = py_lib_temp
-py_inc = '${PYTHON_INCLUDE_DIRS}'
 sys_dlls = '${SYS_DLL_DIR}'
 py_dest = '${PYTHON_DEST_DIR}'
 tmp_prefix = '${MAIN_PACKAGE_DIR}'
