@@ -20,6 +20,8 @@
 **
 *************************************************************************/
 
+#include <QPalette>
+#include <QApplication>
 #include <QDebug>
 #include "BookManipulation/CleanSource.h"
 #include "ResourceObjects/Resource.h"
@@ -43,6 +45,7 @@
 #include "Tabs/WellFormedContent.h"
 #include "Tabs/TabBar.h"
 
+
 TabManager::TabManager(QWidget *parent)
     :
     QTabWidget(parent),
@@ -171,6 +174,14 @@ void TabManager::ReloadTabDataForResources(const QList<Resource *> &resources)
 
 void TabManager::ReopenTabs()
 {
+#ifdef Q_OS_MAC
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    // for some reason using Qt6 the Tab Manager is not inheritiing the dark/light color change
+    // from its parents when the user changes them and then it overrides the CodeView palette change
+    QPalette app_pal = QApplication::palette();
+    setPalette(app_pal);
+#endif
+#endif
     ContentTab *currentTab = GetCurrentContentTab();
     QList<Resource *> resources = GetTabResources();
     foreach(Resource *resource, resources) {
@@ -549,7 +560,7 @@ bool TabManager::SwitchedToExistingTab(const Resource *resource,
         if (flow_tab != NULL) {
             if (!caret_location_to_scroll_to.isEmpty()) {
                 flow_tab->ScrollToCaretLocation(caret_location_to_scroll_to);
-            } else if (position_to_scroll_to > 0) {
+            } else if (position_to_scroll_to >= 0) {
                 flow_tab->ScrollToPosition(position_to_scroll_to);
             } else if (!fragment.toString().isEmpty()) {
                 flow_tab->ScrollToFragment(fragment.toString());
@@ -559,7 +570,7 @@ bool TabManager::SwitchedToExistingTab(const Resource *resource,
 
 
             // manually update the Preview Location
-            // flow_tab->EmitScrollPreviewImmediately();
+            flow_tab->EmitScrollPreviewImmediately();
 
             return true;
         }
@@ -567,7 +578,7 @@ bool TabManager::SwitchedToExistingTab(const Resource *resource,
         TextTab *text_tab = qobject_cast<TextTab *>(tab);
 
         if (text_tab != NULL) {
-            if (position_to_scroll_to > 0) {
+            if (position_to_scroll_to >= 0) {
                 text_tab->ScrollToPosition(position_to_scroll_to);
             } else {
                 text_tab->ScrollToLine(line_to_scroll_to);
