@@ -27,11 +27,13 @@
 #include <QSize>
 #include <QUrl>
 #include <QDir>
-#include <QtWebEngineWidgets/QWebEngineSettings>
-#include <QtWebEngineWidgets/QWebEngineProfile>
-#include <QtWebEngineWidgets/QWebEnginePage>
-#include <QtWebEngineWidgets/QWebEngineView>
-#include <QtWebEngineWidgets/QWebEngineScript>
+#include <QtWebEngineWidgets>
+#include <QtWebEngineCore>
+#include <QWebEngineSettings>
+#include <QWebEngineProfile>
+#include <QWebEnginePage>
+#include <QWebEngineView>
+#include <QWebEngineScript>
 #include <QApplication>
 #include <QGuiApplication>
 #include <QDebug>
@@ -46,6 +48,14 @@
 
 #define DBG if(0)
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    #define QT_ENUM_SKIPEMPTYPARTS Qt::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS Qt::KeepEmptyParts
+#else
+    #define QT_ENUM_SKIPEMPTYPARTS QString::SkipEmptyParts
+    #define QT_ENUM_KEEPEMPTYPARTS QString::KeepEmptyParts
+#endif
+
 const QString SET_CURSOR_JS2 =
     "var range = document.createRange();"
     "range.setStart(element, 0);"
@@ -103,6 +113,7 @@ ViewPreview::ViewPreview(QWidget *parent)
     page()->settings()->setDefaultTextEncoding("UTF-8");
     // Javascript is allowed 
     page()->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, (settings.javascriptOn() == 1));
+    page()->settings()->setAttribute(QWebEngineSettings::JavascriptCanOpenWindows, (settings.javascriptOn() == 1));
     // Allow epubs to access remote resources via the net
     page()->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls, (settings.remoteOn() == 1));
     page()->settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
@@ -212,6 +223,7 @@ void ViewPreview::Zoom()
 
 void ViewPreview::UpdateDisplay()
 {
+#if 0
     SettingsStore settings;
     float stored_factor = settings.zoomWeb();
 
@@ -219,6 +231,7 @@ void ViewPreview::UpdateDisplay()
         m_CurrentZoomFactor = stored_factor;
         Zoom();
     }
+#endif
 }
 
 void ViewPreview::SetPreviewColors(const QString &bg, const QString &fg)
@@ -289,6 +302,9 @@ void ViewPreview::LoadingProgress(int progress)
         m_isLoadFinished = true;
         m_LoadOkay = true;
     }
+    if (zoomFactor() != m_CurrentZoomFactor) {
+        setZoomFactor(m_CurrentZoomFactor);
+    }
     emit ViewProgress(progress);
 }
 
@@ -377,11 +393,15 @@ void ViewPreview::WebPageJavascriptOnLoad()
     DBG qDebug() << "WebPageJavascriptOnLoad with m_CustomSetDocumentInProgress: " << m_CustomSetDocumentInProgress;
     m_isLoadFinished = true;
     if (m_CustomSetDocumentInProgress) {
+        // setZoomFactor(m_CurrentZoomFactor);
         if (!m_pendingScrollToFragment.isEmpty()) {
             ScrollToFragment(m_pendingScrollToFragment);
             m_pendingScrollToFragment.clear();
         } else {
-            executeCaretUpdateInternal();
+            // Zoom must be complete before scrolling to an element and centering on it
+            // *but* is not instantaneous.
+            // It is better to delay this and handle it in PreviewWindow
+            // executeCaretUpdateInternal();
         }
         m_CustomSetDocumentInProgress = false;
     }
@@ -430,7 +450,7 @@ QList<ElementIndex> ViewPreview::ConvertQWebPathToHierarchy(const QString & webp
 {
     // The location element hierarchy encoded in a string
     QString location_string = webpath;
-    QStringList elements    = location_string.split(",", QString::SkipEmptyParts);
+    QStringList elements    = location_string.split(",", QT_ENUM_SKIPEMPTYPARTS);
     QList<ElementIndex> location;
     foreach(QString element, elements) {
         ElementIndex new_element;
