@@ -28,19 +28,20 @@
 #include <QtCore/QDir>
 #include <QtCore/QLibraryInfo>
 #include <QStyleFactory>
-#include <QtCore/QTextCodec>
+#include <QTextCodec>
 #include <QtCore/QThreadPool>
 #include <QtCore/QTranslator>
 #include <QtCore/QStandardPaths>
 #include <QtWidgets/QApplication>
 #include <QtWidgets/QMessageBox>
-#include <QXmlStreamReader>
 #include <QResource>
 #include <QFile>
 #include <QFileInfo>
 #include <QTextStream>
 #include <QFontMetrics>
-#include <QtWebEngineWidgets/QWebEngineProfile>
+#include <QtWebEngineWidgets>
+#include <QtWebEngineCore>
+#include <QWebEngineProfile>
 
 #if QT_VERSION >= QT_VERSION_CHECK(5, 12, 0)
 #include <QWebEngineUrlScheme>
@@ -260,7 +261,7 @@ void VerifyPlugins()
     pdb->load_plugins_from_disk();
 }
 
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void setupHighDPI()
 {
     bool has_env_setting = false;
@@ -289,15 +290,17 @@ void setupHighDPI()
         }
     }
 }
-
+#endif
 
 // Application entry point
 int main(int argc, char *argv[])
 {
-#if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
-    QT_REQUIRE_VERSION(argc, argv, "5.9.0");
-#else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+  #if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
+    QT_REQUIRE_VERSION(argc, argv, "5.10.0");
+  #else
     QT_REQUIRE_VERSION(argc, argv, "5.12.3");
+  #endif
 #endif
 
 #if !defined(Q_OS_WIN32) && !defined(Q_OS_MAC)
@@ -335,10 +338,12 @@ int main(int argc, char *argv[])
     QWebEngineUrlScheme::registerScheme(sigilScheme);
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #ifndef Q_OS_MAC
     setupHighDPI();
 #endif
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
 
     // many qtbugs related to mixing 32 and 64 bit qt apps when shader disk cache is used
     // Only use if using Qt5.9.0 or higher
@@ -347,7 +352,7 @@ int main(int argc, char *argv[])
 #endif
 
     // Disable ? as Sigil does not use QWhatsThis
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QCoreApplication::setAttribute(Qt::AA_DisableWindowContextHelpButton);
 #endif
 
@@ -360,6 +365,27 @@ int main(int argc, char *argv[])
     // QtWebEngine may need this
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
 
+#if defined(Q_OS_WIN32)
+    SettingsStore ss;
+    if (ss.enableAltGr()) {
+        qputenv("QT_QPA_PLATFORM", "windows:altgr");
+    }
+#endif
+
+    // enable disabling of gpu acceleration for QtWebEngine.
+    // append to current environment variable contents as numerous chromium 
+    // switches exist that may be useful
+    SettingsStore nss;
+    if (nss.disableGPU()) {
+        QString current_flags = Utility::GetEnvironmentVar("QTWEBENGINE_CHROMIUM_FLAGS");
+        if (current_flags.isEmpty()) {
+            current_flags = "--disable-gpu";
+        } else if (!current_flags.contains("--disable-gpu")) {
+            current_flags += " --disable-gpu";
+        }
+        qputenv("QTWEBENGINE_CHROMIUM_FLAGS", current_flags.toUtf8());
+    }
+
     MainApplication app(argc, argv);
 
 #ifdef Q_OS_MAC
@@ -436,7 +462,9 @@ int main(int argc, char *argv[])
         if (Utility::WindowsShouldUseDarkMode()) {
             // Apply custom dark style
             app.setStyle(new SigilDarkStyle);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             app.setPalette(QApplication::style()->standardPalette());
+#endif
         }
 #endif
 #endif
@@ -586,8 +614,19 @@ int main(int argc, char *argv[])
         QStringList arguments = QCoreApplication::arguments();
 
 #ifdef Q_OS_MAC
-        // now process main app events so that any startup 
+        // now process main app events so that any startup
         // FileOpen event will be processed for macOS
+
+        // Note: this is a race between when macOS
+        // sends out a signal that there is a file being launched simultaneously
+        // and us reaching this point to check if there is such a file
+
+        // So give Qt lots of time to process the macOS signal and convert
+        // it into its own Qt signal that passes along the file path
+        QCoreApplication::processEvents();
+        QCoreApplication::processEvents();
+        QCoreApplication::processEvents();
+        QCoreApplication::processEvents();
         QCoreApplication::processEvents();
 
         QString filepath = filter->getInitialFilePath();
@@ -597,7 +636,9 @@ int main(int argc, char *argv[])
             arguments << QFileInfo(filepath).absoluteFilePath();
         }
 
-        if (filepath.isEmpty()) filter->setInitialFilePath(QString("placeholder"));
+        if (filepath.isEmpty()) {
+            filter->setInitialFilePath(QString("placeholder"));
+        }
 #endif
 
         if (arguments.contains("-t")) {
