@@ -1,3 +1,26 @@
+/************************************************************************
+**
+**  Copyright (C) 2015-2021 Kevin B. Hendricks, Stratford Ontario Canada
+**  Copyright (C) 2015-2021 Doug Massay
+**  Copyright (C) 2009-2011 Strahinja Markovic  <strahinja.markovic@gmail.com>
+**
+**  This file is part of Sigil.
+**
+**  Sigil is free software: you can redistribute it and/or modify
+**  it under the terms of the GNU General Public License as published by
+**  the Free Software Foundation, either version 3 of the License, or
+**  (at your option) any later version.
+**
+**  Sigil is distributed in the hope that it will be useful,
+**  but WITHOUT ANY WARRANTY; without even the implied warranty of
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+**  GNU General Public License for more details.
+**
+**  You should have received a copy of the GNU General Public License
+**  along with Sigil.  If not, see <http://www.gnu.org/licenses/>.
+**
+*************************************************************************/
+
 #include <QString>
 #include <QStringList>
 #include "sigil_constants.h"
@@ -15,11 +38,16 @@ const QStringList PYTHON_SYS_PATHS = QStringList() << "/Lib" << "/DLLs" << "/Lib
 const QString SIGIL_PREFS_DIR = QString(getenv("SIGIL_PREFS_DIR"));
 #endif
 
+// CMAKE configuration -DDISABLE_UPDATE_CHECK (0 or 1)
+const bool DONT_CHECK_FOR_UPDATES = DONT_CHECK_UPDATES;
+
 #if __APPLE__
 const QString PATH_LIST_DELIM = ":";
-const QString PYTHON_MAIN_BIN_PATH = "/Frameworks/Python.framework/Versions/3.7/bin/python3";
-const QString PYTHON_SITE_PACKAGES = "/Frameworks/Python.framework/Versions/3.7/lib/python3.7/site-packages";
-const QStringList PYTHON_SYS_PATHS = QStringList () << "/plat-darwin" << "/lib-dynload" << "/site-packages";
+const QString PYTHON_MAIN_PREFIX = "/Frameworks/Python.framework/Versions/3.9";
+const QString PYTHON_MAIN_BIN_PATH = PYTHON_MAIN_PREFIX + "/bin/python3";
+const QString PYTHON_LIB_PATH = "/lib/python3.9";
+const QString PYTHON_SITE_PACKAGES = PYTHON_MAIN_PREFIX + PYTHON_LIB_PATH + "/site-packages";
+const QStringList PYTHON_SYS_PATHS = QStringList () << "/lib-dynload" << "/site-packages";
 #endif
 
 #if !defined(_WIN32) && !defined(__APPLE__)
