@@ -25,8 +25,9 @@
 #ifndef SG_CONSTANTS_H
 #define SG_CONSTANTS_H
 
+#include <QStringList>
+
 class QString;
-class QStringList;
 
 // These enable us to use constants defined
 // in one CPP file to be used in another
